@@ -20,6 +20,48 @@ const testDetailsPage = (subTitle, alertName, expectLabel = true) => {
   }
 };
 
+const testSilenceTimeInputs = async () => {
+  // Default start and end times
+  expect(monitoringView.silenceStartNowCheckbox.getAttribute('checked')).toBeTruthy();
+  expect(monitoringView.silenceStartsAtInput.getAttribute('value')).toEqual('Now');
+  expect(monitoringView.silenceDurationMenuButton.getText()).toEqual('2h');
+  expect(monitoringView.silenceEndsAtInput.getAttribute('value')).toEqual('2h from now');
+
+  // Change duration
+  await monitoringView.silenceDurationMenuButton.click();
+  await monitoringView.wait(until.presenceOf(monitoringView.silenceDurationOption('1h')));
+  await monitoringView.silenceDurationOption('1h').click();
+  expect(monitoringView.silenceEndsAtInput.getAttribute('value')).toEqual('1h from now');
+
+  // Change to not start now
+  await monitoringView.silenceStartNowCheckbox.click();
+  expect(monitoringView.silenceStartNowCheckbox.getAttribute('checked')).toBeFalsy();
+  // Allow for some difference in times
+  expect(monitoringView.silenceStartsAtInput.getAttribute('value')).not.toEqual('Now');
+  expect(monitoringView.silenceStartsAtInput.getAttribute('value')).toBeTruthy();
+  monitoringView.silenceStartsAtInput.getAttribute('value').then((start: string) => {
+    expect(Date.parse(start) - Date.now()).toBeLessThan(10000);
+    monitoringView.silenceEndsAtInput.getAttribute('value').then((end: string) => {
+      expect(Date.parse(end) - Date.parse(start)).toEqual(60 * 60 * 1000);
+    });
+  });
+
+  // Invalid start time
+  await monitoringView.silenceStartsAtInput.sendKeys('abc');
+  expect(monitoringView.silenceEndsAtInput.getAttribute('value')).toEqual('-');
+
+  // Change to back to start now
+  await monitoringView.silenceStartNowCheckbox.click();
+  expect(monitoringView.silenceStartNowCheckbox.getAttribute('checked')).toBeTruthy();
+  expect(monitoringView.silenceEndsAtInput.getAttribute('value')).toEqual('1h from now');
+
+  // Change duration back again
+  await monitoringView.silenceDurationMenuButton.click();
+  await monitoringView.wait(until.presenceOf(monitoringView.silenceDurationOption('2h')));
+  await monitoringView.silenceDurationOption('2h').click();
+  expect(monitoringView.silenceEndsAtInput.getAttribute('value')).toEqual('2h from now');
+};
+
 describe('Monitoring: Alerts', () => {
   afterEach(() => {
     checkLogs();
@@ -66,8 +108,10 @@ describe('Monitoring: Alerts', () => {
   });
 
   it('creates a new Silence from an existing alert', async () => {
-    await crudView.clickDetailsPageAction('Silence Alert');
+    await monitoringView.actionButton.click();
     await monitoringView.wait(until.presenceOf(monitoringView.saveButton));
+    await testSilenceTimeInputs();
+    await monitoringView.commentTextarea.sendKeys('Test Comment');
     await monitoringView.saveButton.click();
     expect(crudView.errorMessage.isPresent()).toBe(false);
 
@@ -116,9 +160,7 @@ describe('Monitoring: Silences', () => {
     await sidenavView.clickNavLink(['Monitoring', 'Alerting']);
     await crudView.isLoaded();
     await horizontalnavView.clickHorizontalTab('Silences');
-    expect(monitoringView.helpText.getText()).toContain(
-      'Silences temporarily mute alerts based on a set of conditions',
-    );
+    await monitoringView.wait(until.presenceOf(monitoringView.createButton));
   });
 
   it('does not have a namespace dropdown', async () => {
@@ -128,8 +170,10 @@ describe('Monitoring: Silences', () => {
   it('creates a new Silence', async () => {
     await monitoringView.createButton.click();
     await monitoringView.wait(until.presenceOf(monitoringView.matcherNameInput));
+    await testSilenceTimeInputs();
     await monitoringView.matcherNameInput.sendKeys('alertname');
     await monitoringView.matcherValueInput.sendKeys(testAlertName);
+    await monitoringView.commentTextarea.sendKeys('Test Comment');
     await monitoringView.saveButton.click();
     expect(crudView.errorMessage.isPresent()).toBe(false);
   });
@@ -162,14 +206,14 @@ describe('Monitoring: Silences', () => {
   it('edits the Silence', async () => {
     await crudView.clickDetailsPageAction('Edit Silence');
     await monitoringView.wait(until.presenceOf(monitoringView.commentTextarea));
-    await monitoringView.commentTextarea.sendKeys('Test Comment');
+    await monitoringView.commentTextarea.sendKeys(' (edited)');
     await monitoringView.saveButton.click();
     expect(crudView.errorMessage.isPresent()).toBe(false);
 
     // After editing the Silence, should be redirected to its details page, where we check that the edit is reflected
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingSilenceIcon));
     testDetailsPage('Silence Details', testAlertName);
-    expect(monitoringView.silenceComment.getText()).toEqual('Test Comment');
+    expect(monitoringView.silenceComment.getText()).toEqual('Test Comment (edited)');
   });
 
   it('expires the Silence', async () => {
@@ -192,7 +236,7 @@ describe('Alertmanager: YAML', () => {
     checkErrors();
   });
 
-  it('displays the Alermanager YAML page', async () => {
+  it('displays the Alertmanager YAML page', async () => {
     await sidenavView.clickNavLink(['Administration', 'Cluster Settings']);
     await crudView.isLoaded();
     await horizontalnavView.clickHorizontalTab('Global Configuration');
@@ -226,7 +270,7 @@ describe('Alertmanager: Configuration', () => {
     checkErrors();
   });
 
-  it('displays the Alermanager Configuration Details page', async () => {
+  it('displays the Alertmanager Configuration Details page', async () => {
     await browser.get(`${appHost}/monitoring/alertmanagerconfig`);
     await crudView.isLoaded();
     expect(monitoringView.alertRoutingHeader.getText()).toContain('Alert Routing');
@@ -308,6 +352,9 @@ describe('Alertmanager: Configuration', () => {
     expect(monitoringView.saveButton.isEnabled()).toBe(true); // subform valid & labels provided, save should be enabled at this point
     await monitoringView.saveButton.click();
     await crudView.isLoaded();
+    await monitoringView.wait(until.elementToBeClickable(crudView.nameFilter));
+    await crudView.nameFilter.clear();
+    await crudView.nameFilter.sendKeys('MyReceiver');
     monitoringView.getFirstRowAsText().then((text) => {
       expect(text).toEqual('MyReceiver pagerduty severity = warning');
     });
@@ -315,7 +362,10 @@ describe('Alertmanager: Configuration', () => {
 
   it('edits a receiver correctly', async () => {
     await crudView.isLoaded();
-    expect(crudView.resourceRows.count()).toBe(2);
+    await monitoringView.wait(until.elementToBeClickable(crudView.nameFilter));
+    await crudView.nameFilter.clear();
+    await crudView.nameFilter.sendKeys('MyReceiver');
+    expect(crudView.resourceRows.count()).toBe(1);
     await monitoringView.clickFirstRowKebabAction('Edit Receiver');
     await browser.wait(until.presenceOf(firstElementByTestID('cancel')));
     expect(firstElementByTestID('receiver-name').getAttribute('value')).toEqual('MyReceiver');
@@ -338,7 +388,9 @@ describe('Alertmanager: Configuration', () => {
 
     await monitoringView.saveButton.click();
     await crudView.isLoaded();
-
+    await monitoringView.wait(until.elementToBeClickable(crudView.nameFilter));
+    await crudView.nameFilter.clear();
+    await crudView.nameFilter.sendKeys('MyEditedReceiver');
     monitoringView.getFirstRowAsText().then((text) => {
       expect(text).toEqual('MyEditedReceiver pagerduty cluster = MyCluster');
     });
@@ -347,18 +399,27 @@ describe('Alertmanager: Configuration', () => {
   it('deletes a receiver correctly', async () => {
     await horizontalnavView.clickHorizontalTab('Details');
     await crudView.isLoaded();
-    expect(crudView.resourceRows.count()).toBe(2);
+    await monitoringView.wait(until.elementToBeClickable(crudView.nameFilter));
+    await crudView.nameFilter.clear();
+    await crudView.nameFilter.sendKeys('MyEditedReceiver');
+    expect(crudView.resourceRows.count()).toBe(1);
 
     await monitoringView.clickFirstRowKebabAction('Delete Receiver');
     await browser.wait(until.presenceOf(monitoringView.saveButton));
     await monitoringView.saveButton.click();
 
     await crudView.isLoaded();
-    expect(crudView.resourceRows.count()).toBe(1);
+    await monitoringView.wait(until.elementToBeClickable(crudView.nameFilter));
+    await crudView.nameFilter.clear();
+    await crudView.nameFilter.sendKeys('MyEditedReceiver');
+    expect(crudView.resourceRows.count()).toBe(0);
   });
 
   it('prevents deletion of default receiver', async () => {
     await crudView.isLoaded();
+    await monitoringView.wait(until.elementToBeClickable(crudView.nameFilter));
+    await crudView.nameFilter.clear();
+    await crudView.nameFilter.sendKeys('Default');
     await monitoringView.openFirstRowKebabMenu();
     expect(monitoringView.disabledDeleteReceiverMenuItem.isPresent()).toBe(true);
   });
