@@ -37,7 +37,7 @@ import { OSDSizeDropdown } from '../../utils/osd-size-dropdown';
 import { cephStorageLabel } from '../../selectors';
 import NodeTable from './node-list';
 import { PVsAvailableCapacity } from './pvs-available-capacity';
-import { OCS_FLAG, OCS_CONVERGED_FLAG } from '../../features';
+import { OCS_FLAG, OCS_CONVERGED_FLAG, OCS_INDEPENDENT_FLAG } from '../../features';
 import './ocs-install.scss';
 
 const makeLabelNodesRequest = (selectedNodes: NodeKind[]): Promise<NodeKind>[] => {
@@ -107,6 +107,7 @@ export const CreateOCSServiceForm = withHandlePromise<
     // eslint-disable-next-line promise/catch-or-return
     handlePromise(makeOCSRequest(selectedNodes, storageClass, osdSize)).then(() => {
       dispatch(setFlag(OCS_CONVERGED_FLAG, true));
+      dispatch(setFlag(OCS_INDEPENDENT_FLAG, false));
       dispatch(setFlag(OCS_FLAG, true));
       history.push(
         `/k8s/ns/${ns}/clusterserviceversions/${appName}/${referenceForModel(
@@ -133,7 +134,7 @@ export const CreateOCSServiceForm = withHandlePromise<
         <p>
           Selected nodes will be labeled with{' '}
           <code>cluster.ocs.openshift.io/openshift-storage=&quot;&quot;</code> to create the OCS
-          Service.
+          Service unless they are already labeled.
         </p>
         <Alert
           className="co-alert"
