@@ -1,5 +1,7 @@
 import { FirehoseResource } from '@console/internal/components/utils/index';
 import { referenceForModel } from '@console/internal/module/k8s/k8s';
+import { PersistentVolumeModel } from '@console/internal/models';
+import { WatchK8sResource } from '@console/internal/components/utils/k8s-watch-hook';
 import { CephClusterModel } from '../models';
 
 export const cephClusterResource: FirehoseResource = {
@@ -8,10 +10,9 @@ export const cephClusterResource: FirehoseResource = {
   isList: true,
   prop: 'ceph',
 };
-export enum StorageDashboardResource {
-  CEPH_CLUSTER_RESOURCE = 'CEPH_CLUSTER_RESOURCE',
-}
 
-export const STORAGE_HEALTH_RESOURCES = {
-  [StorageDashboardResource.CEPH_CLUSTER_RESOURCE]: cephClusterResource,
+export const pvResource: WatchK8sResource = {
+  kind: PersistentVolumeModel.kind,
+  namespaced: false,
+  isList: true,
 };
