@@ -15,13 +15,17 @@ const StatusIconAndText: React.FC<StatusIconAndTextProps> = ({
   spin,
   iconOnly,
   noTooltip,
+  className,
 }) => {
   if (!title) {
     return <>{DASH}</>;
   }
 
   return (
-    <span className="co-icon-and-text" title={iconOnly && !noTooltip ? title : undefined}>
+    <span
+      className={classNames('co-icon-and-text', className)}
+      title={iconOnly && !noTooltip ? title : undefined}
+    >
       {icon &&
         React.cloneElement(icon, {
           className: classNames(
