@@ -1,6 +1,18 @@
-import { K8sResourceKind, PodKind, RouteKind, EventKind } from '@console/internal/module/k8s';
+import { K8sResourceKind, PodKind, RouteKind } from '@console/internal/module/k8s';
 import { DEPLOYMENT_STRATEGY } from '../constants';
 import { OverviewItemAlerts, PodControllerOverviewItem } from './pod';
+import { ClusterServiceVersionKind } from '@console/operator-lifecycle-manager';
+
+export type APIError = {
+  status?: string;
+  message?: string;
+  reason?: string;
+  details?: {
+    name?: string;
+    kind?: string;
+  };
+  code?: number;
+};
 
 export type BuildConfigOverviewItem = K8sResourceKind & {
   builds: K8sResourceKind[];
@@ -21,8 +33,12 @@ export type OverviewItem<T = K8sResourceKind> = {
   configurations?: K8sResourceKind[];
   ksservices?: K8sResourceKind[];
   revisions?: K8sResourceKind[];
-  events?: EventKind[];
   isOperatorBackedService?: boolean;
+  isMonitorable?: boolean;
+};
+
+export type OperatorBackedServiceKindMap = {
+  [name: string]: ClusterServiceVersionKind;
 };
 
 export type DeploymentStrategy = DEPLOYMENT_STRATEGY.recreate | DEPLOYMENT_STRATEGY.rolling;
