@@ -15,7 +15,7 @@ import {
   sampleKnativeDeployments,
   MockKnativeResources,
 } from '@console/dev-console/src/components/topology/__tests__/topology-knative-test-data';
-import { TransformResourceData } from '../resource-utils';
+import { TransformResourceData } from '../transformResourceData';
 
 declare global {
   namespace jest {
@@ -84,7 +84,7 @@ describe('TransformResourceData', () => {
     const transformedData = transformResourceData.createDeploymentConfigItems(
       sampleDeploymentConfigs.data,
     );
-    expect(transformedData).toHaveLength(1);
+    expect(transformedData).toHaveLength(2);
     expect(transformedData[0]).toHaveProperties(dcKeys);
   });
 
@@ -92,7 +92,7 @@ describe('TransformResourceData', () => {
     const transformedData = transformResourceData.createDeploymentConfigItems(
       sampleDeploymentConfigs.data,
     );
-    expect(transformedData).toHaveLength(1);
+    expect(transformedData).toHaveLength(2);
     expect(transformedData[0]).not.toHaveProperties([...dcKeys, 'revisions']);
   });
 
@@ -150,7 +150,7 @@ describe('TransformResourceData', () => {
     const transformedData = transformResourceData.getPodsForDeploymentConfigs(
       sampleDeploymentConfigs.data,
     );
-    expect(transformedData).toHaveLength(1);
+    expect(transformedData).toHaveLength(2);
     expect(transformedData[0]).toHaveProperties(podRCKeys);
   });
 
