@@ -20,7 +20,9 @@ export const builderImage = element(
   by.cssContainingText('.pf-c-card.odc-builder-image-card', 'Node.js'),
 );
 export const buildImageVersion = element(by.id('form-dropdown-image-tag-field'));
-export const createButton = element(by.css('[data-test-id="import-git-create-button"]'));
+export const createButton = element(by.css('[data-test-id="import-git-form"]')).element(
+  by.css('[data-test-id="submit-button"]'),
+);
 export const builderImageVersionName = element(by.id('8-link'));
 
 export const navigateImportFromGit = async function() {
@@ -89,6 +91,7 @@ export const addApplication = async function(name: string, nodeName: string) {
 };
 
 export const addApplicationWithExistingApps = async function(name: string, nodeName: string) {
+  await browser.wait(until.visibilityOf(applicationSelector));
   await browser.wait(until.elementToBeClickable(applicationSelector));
   await applicationSelector.click();
   await browser.wait(until.presenceOf(applicationDropdown));
