@@ -1,8 +1,8 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import { Form, ActionGroup, ButtonVariant, Button } from '@patternfly/react-core';
+import { Form } from '@patternfly/react-core';
 import { FormikProps, FormikValues } from 'formik';
-import { ButtonBar } from '@console/internal/components/utils';
+import { FormFooter } from '@console/shared/src/components/form-utils';
 import { GitImportFormProps } from './import-types';
 import GitSection from './git/GitSection';
 import BuilderSection from './builder/BuilderSection';
@@ -23,7 +23,7 @@ const GitImportForm: React.FC<FormikProps<FormikValues> & GitImportFormProps> =
   dirty,
   projects,
 }) => (
-  <Form onSubmit={handleSubmit}>
+  <Form onSubmit={handleSubmit} data-test-id="import-git-form">
     <GitSection />
     <BuilderSection image={values.image} builderImages={builderImages} />
     <DockerSection buildStrategy={values.build.strategy} />
@@ -31,24 +31,18 @@ const GitImportForm: React.FC<FormikProps<FormikValues> & GitImportFormProps> =
       project={values.project}
       noProjectsAvailable={projects.loaded && _.isEmpty(projects.data)}
     />
-    <PipelineSection />
     <ResourceSection />
+    <PipelineSection builderImages={builderImages} />
     <AdvancedSection values={values} />
-    <ButtonBar errorMessage={status && status.submitError} inProgress={isSubmitting}>
-      <ActionGroup className="pf-c-form">
-        <Button
-          type="submit"
-          variant={ButtonVariant.primary}
-          isDisabled={!dirty || !_.isEmpty(errors)}
-          data-test-id="import-git-create-button"
-        >
-          Create
-        </Button>
-        <Button type="button" variant={ButtonVariant.secondary} onClick={handleReset}>
-          Cancel
-        </Button>
-      </ActionGroup>
-    </ButtonBar>
+    <FormFooter
+      handleReset={handleReset}
+      errorMessage={status && status.submitError}
+      isSubmitting={isSubmitting}
+      submitLabel="Create"
+      sticky
+      disableSubmit={!dirty || !_.isEmpty(errors)}
+      resetLabel="Cancel"
+    />
   </Form>
 );
 
