@@ -1,5 +1,6 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import * as fuzzy from 'fuzzysearch';
 import { useFormikContext, FormikValues, getIn } from 'formik';
 import { ValidatedOptions } from '@patternfly/react-core';
 import { DropdownField } from '@console/shared';
@@ -11,6 +12,7 @@ import {
   getPorts,
   getSuggestedName,
   makePortName,
+  imageStreamLabels,
 } from '../../../utils/imagestream-utils';
 import { ImageStreamContext } from './ImageStreamContext';
 
@@ -18,6 +20,7 @@ const ImageStreamTagDropdown: React.FC = () => {
   let imageStreamTagList = {};
   const {
     values: {
+      name: resourceName,
       imageStream,
       application,
       formType,
@@ -40,17 +43,24 @@ const ImageStreamTagDropdown: React.FC = () => {
       setFieldValue('isSearchingForImage', true);
       k8sGet(ImageStreamTagModel, `${imageStream.image}:${selectedTag}`, imageStream.namespace)
         .then((imageStreamImport) => {
-          const { image, tag, status } = imageStreamImport;
+          const {
+            image,
+            tag,
+            status,
+            metadata: { labels },
+          } = imageStreamImport;
+
+          const imgStreamLabels = _.pick(labels, imageStreamLabels);
           const name = imageStream.image;
           const isi = { name, image, tag, status };
           const ports = getPorts(isi);
           setFieldValue('isSearchingForImage', false);
           setFieldValue('isi.name', name);
-          setFieldValue('isi.image', image);
+          setFieldValue('isi.image', _.merge(image, { metadata: { labels: imgStreamLabels } }));
           setFieldValue('isi.tag', selectedTag);
           setFieldValue('isi.ports', ports);
           setFieldValue('image.ports', ports);
-          formType !== 'edit' && setFieldValue('name', getSuggestedName(name));
+          !resourceName && formType !== 'edit' && setFieldValue('name', getSuggestedName(name));
           application.selectedKey !== UNASSIGNED_KEY &&
             !application.name &&
             setFieldValue('application.name', `${getSuggestedName(name)}-app`);
@@ -75,6 +85,7 @@ const ImageStreamTagDropdown: React.FC = () => {
       formType,
       application.selectedKey,
       application.name,
+      resourceName,
       setValidated,
       imageStream.namespace,
       initialValues.route.targetPort,
@@ -111,6 +122,7 @@ const ImageStreamTagDropdown: React.FC = () => {
       label="Tag"
       items={imageStreamTagList}
       key={imageStream.image}
+      autocompleteFilter={fuzzy}
       title={
         imageStream.tag ||
         (isNamespaceSelected && isImageStreamSelected && !isTagsAvailable ? 'No Tag' : 'Select Tag')
