@@ -2,11 +2,13 @@ import * as React from 'react';
 import { shallow } from 'enzyme';
 import { SelectOption } from '@patternfly/react-core';
 import FilterDropdown from '../FilterDropdown';
-import { DisplayFilters } from '../filter-utils';
+import { DisplayFilters } from '../filter-types';
 
 const VALID_FILTERS = {
   podCount: true,
   eventSources: true,
+  virtualMachines: true,
+  showLabels: true,
   knativeServices: true,
   appGrouping: true,
   operatorGrouping: true,
@@ -26,7 +28,7 @@ describe(FilterDropdown.displayName, () => {
     expect(wrapper.exists()).toBeTruthy();
   });
 
-  it('should have 6 filters in total', () => {
+  it('should have 8 filters in total', () => {
     const wrapper = shallow(<FilterDropdown filters={dropdownFilter} onChange={onChange} />);
     expect(wrapper.find(SelectOption)).toHaveLength(Object.keys(VALID_FILTERS).length);
   });
