@@ -1,14 +1,12 @@
-import * as _ from 'lodash';
+import { PipelineModel, PipelineRunModel } from '../../models';
 import {
   stopPipelineRun,
   rerunPipelineAndRedirect,
   reRunPipelineRun,
   startPipeline,
-  getPipelineRunData,
-  migratePipelineRun,
+  getPipelineKebabActions,
 } from '../pipeline-actions';
 import { PipelineRun, Pipeline } from '../pipeline-augment';
-import { PipelineModel, PipelineRunModel } from '../../models';
 
 export const actionPipelines: Pipeline[] = [
   {
@@ -24,6 +22,9 @@ export const actionPipelines: Pipeline[] = [
     apiVersion: 'abhiapi/v1',
     kind: 'Pipeline',
     metadata: { name: 'danaerys-targaeryen', namespace: 'corazon' },
+    spec: {
+      tasks: [],
+    },
   },
 ];
 
@@ -84,62 +85,31 @@ describe('PipelineAction testing stopPipelineRun create correct labels and callb
   });
 });
 
-describe('PipelineAction testing getPipelineRunData', () => {
-  it('expect null to be returned when no arguments are passed', () => {
-    const runData = getPipelineRunData();
-    expect(runData).toBeNull();
+describe('getPipelineKebabActions', () => {
+  it('expect Remove Trigger option is present', () => {
+    const pipelineKebabActions = getPipelineKebabActions(actionPipelineRuns[0], true);
+    expect(pipelineKebabActions.length).toBe(6);
+    expect(pipelineKebabActions[3](PipelineModel, actionPipelines[0]).label).toBe('Remove Trigger');
   });
-
-  it('expect pipeline run data to be returned when only Pipeline argument is passed', () => {
-    const runData = getPipelineRunData(actionPipelines[0]);
-    expect(runData).not.toBeNull();
+  it('expect Remove Trigger option is not present', () => {
+    const pipelineKebabActions = getPipelineKebabActions(actionPipelineRuns[0], false);
+    expect(pipelineKebabActions.length).toBe(5);
+    expect(pipelineKebabActions[3](PipelineModel, actionPipelines[0]).label).not.toBe(
+      'Remove Trigger',
+    );
   });
-
-  it('expect pipeline run data to be returned when only PipelineRun argument is passed', () => {
-    const runData = getPipelineRunData(null, actionPipelineRuns[0]);
-    expect(runData).not.toBeNull();
+  it('expect Start Last Run option is present', () => {
+    const pipelineKebabActions = getPipelineKebabActions(actionPipelineRuns[0], false);
+    expect(pipelineKebabActions.length).toBe(5);
+    expect(pipelineKebabActions[1](PipelineRunModel, actionPipelineRuns[0]).label).toBe(
+      'Start Last Run',
+    );
   });
-
-  it('expect params to not have default key in the pipeline run data', () => {
-    const runData = getPipelineRunData(actionPipelines[0]);
-    const { params } = runData.spec;
-    expect(params[0].name).toBe('APP_NAME');
-    expect(params[0].value).toBe('default-app-name');
-    expect(_.has(params[0], 'default')).toBeFalsy();
-  });
-});
-
-describe('PipelineAction testing migratePipelineRun', () => {
-  it('expect migratePipelineRun to do nothing when there is no migration needed', () => {
-    // Same instance should be returned if there was no need for a migration
-    expect(migratePipelineRun(actionPipelineRuns[0])).toEqual(actionPipelineRuns[0]);
-  });
-
-  it('expect migratePipelineRun to handle serviceAccount to serviceAccountName migration (Operator 0.9.x)', () => {
-    type OldPipelineRun = PipelineRun & {
-      spec: {
-        serviceAccount: string;
-      };
-    };
-    const serviceAccountValue = 'serviceAccountValue';
-    const plr: OldPipelineRun = {
-      ...actionPipelineRuns[0],
-      spec: {
-        ...actionPipelineRuns[0].spec,
-        serviceAccount: serviceAccountValue,
-      },
-    };
-
-    const result: PipelineRun = migratePipelineRun(plr);
-
-    // Should be a new instance
-    expect(result).not.toEqual(plr);
-
-    // The value should have moved
-    expect(result.spec.serviceAccountName).toEqual(serviceAccountValue);
-    expect((result as OldPipelineRun).spec.serviceAccount).toBeUndefined();
-
-    // Should still have other spec properties
-    expect(result.spec.pipelineRef).toEqual(actionPipelineRuns[0].spec.pipelineRef);
+  it('expect Start Last Run option is not present', () => {
+    const pipelineKebabActions = getPipelineKebabActions(undefined, false);
+    expect(pipelineKebabActions.length).toBe(4);
+    expect(pipelineKebabActions[1](PipelineRunModel, actionPipelineRuns[0]).label).not.toBe(
+      'Start Last Run',
+    );
   });
 });
