@@ -1,7 +1,6 @@
 import * as React from 'react';
 import { ListPage } from '@console/internal/components/factory';
 import { referenceForModel } from '@console/internal/module/k8s';
-import { getBadgeFromType } from '@console/shared';
 import { ServiceModel } from '../../models';
 import ServiceList from './ServiceList';
 
@@ -15,7 +14,6 @@ const ServicesPage: React.FC<React.ComponentProps<typeof ListPage>> = (props) =>
     canCreate
     kind={referenceForModel(ServiceModel)}
     ListComponent={ServiceList}
-    badge={getBadgeFromType(ServiceModel.badge)}
   />
 );
 
