@@ -1,6 +1,8 @@
 import * as _ from 'lodash';
-import { K8sResourceKind, PodKind } from '@console/internal/module/k8s';
+import { K8sResourceKind, PodKind, referenceForModel } from '@console/internal/module/k8s';
+import { FirehoseResource } from '@console/internal/components/utils';
 import { KNATIVE_SERVING_LABEL } from '../const';
+import { ServiceModel, RevisionModel, ConfigurationModel, RouteModel } from '../models';
 
 export type KnativeItem = {
   revisions?: K8sResourceKind[];
@@ -12,6 +14,7 @@ export type KnativeItem = {
   eventSourceApiserver?: K8sResourceKind[];
   eventSourceCamel?: K8sResourceKind[];
   eventSourceKafka?: K8sResourceKind[];
+  eventSourceSinkbinding?: K8sResourceKind[];
   pods?: PodKind[];
 };
 
@@ -62,47 +65,54 @@ export const getKnativeServingServices = (dc: K8sResourceKind, props): KnativeIt
   return ksservices && ksservices.length > 0 ? { ksservices } : undefined;
 };
 
-const getEventSourceResource = (
-  dc: K8sResourceKind,
-  { data }: K8sResourceKind,
-): K8sResourceKind[] => {
-  const ownerUid = _.get(dc, ['metadata', 'ownerReferences', '0', 'uid'], null);
-  const eventSourceResources = _.filter(data, (config: K8sResourceKind) => {
-    return ownerUid === _.get(config, ['metadata', 'uid']);
-  });
-  return eventSourceResources;
+export const knativeServingResourcesRevision = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(RevisionModel),
+      namespace,
+      prop: 'revisions',
+      optional: true,
+    },
+  ];
+  return knativeResource;
 };
 
-export const getEventSourceCronjob = (dc: K8sResourceKind, props): KnativeItem | undefined => {
-  const eventSourceCronjob =
-    props && props.eventSourceCronjob && getEventSourceResource(dc, props.eventSourceCronjob);
-  return eventSourceCronjob && eventSourceCronjob.length > 0 ? { eventSourceCronjob } : undefined;
+export const knativeServingResourcesConfigurations = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(ConfigurationModel),
+      namespace,
+      prop: 'configurations',
+      optional: true,
+    },
+  ];
+  return knativeResource;
 };
 
-export const getEventSourceContainer = (dc: K8sResourceKind, props): KnativeItem | undefined => {
-  const eventSourceContainers =
-    props && props.eventSourceContainers && getEventSourceResource(dc, props.eventSourceContainers);
-  return eventSourceContainers && eventSourceContainers.length > 0
-    ? { eventSourceContainers }
-    : undefined;
+export const knativeServingResourcesRoutes = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(RouteModel),
+      namespace,
+      prop: 'ksroutes',
+      optional: true,
+    },
+  ];
+  return knativeResource;
 };
 
-export const getEventSourceApiserver = (dc: K8sResourceKind, props): KnativeItem | undefined => {
-  const eventSourceApiserver =
-    props && props.eventSourceApiserver && getEventSourceResource(dc, props.eventSourceApiserver);
-  return eventSourceApiserver && eventSourceApiserver.length > 0
-    ? { eventSourceApiserver }
-    : undefined;
-};
-
-export const getEventSourceCamel = (dc: K8sResourceKind, props): KnativeItem | undefined => {
-  const eventSourceCamel =
-    props && props.eventSourceCamel && getEventSourceResource(dc, props.eventSourceCamel);
-  return eventSourceCamel && eventSourceCamel.length > 0 ? { eventSourceCamel } : undefined;
-};
-
-export const getEventSourceKafka = (dc: K8sResourceKind, props): KnativeItem | undefined => {
-  const eventSourceKafka =
-    props && props.eventSourceKafka && getEventSourceResource(dc, props.eventSourceKafka);
-  return eventSourceKafka && eventSourceKafka.length > 0 ? { eventSourceKafka } : undefined;
+export const knativeServingResourcesServices = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(ServiceModel),
+      namespace,
+      prop: 'ksservices',
+      optional: true,
+    },
+  ];
+  return knativeResource;
 };
