@@ -1,11 +1,16 @@
-import { $ } from 'protractor';
+import { $, element, by } from 'protractor';
 
 export const diskSource = $('#disk-source');
 export const diskURL = $('#disk-url');
 export const diskContainer = $('#disk-container');
-export const diskNamespace = $('#disk-namespace');
+export const diskNamespace = $('#disk-pvc-namespace');
 export const diskPVC = $('#disk-pvc');
 export const diskName = $('#disk-name');
 export const diskSize = $('#disk-size-row-size');
 export const diskInterface = $('#disk-interface');
 export const diskStorageClass = $('#disk-storage-class');
+export const advancedDrawerToggle = element(by.buttonText('Advanced'));
+export const diskVolumeMode = $('#disk-volume-mode');
+export const diskAccessMode = $('#disk-access-mode');
+
+export const diskInterfaceHelper = $('#disk-interface-helper');
