@@ -1,29 +1,13 @@
 import { OrderedSet } from 'immutable';
 import { CommonData, VMSettingsField, VMWizardProps } from '../../types';
-import { asHidden, asRequired } from '../../utils/utils';
+import { asDisabled, asHidden, asRequired } from '../../utils/utils';
 import { ProvisionSource } from '../../../../constants/vm/provision-source';
-import { getProviders } from '../../provider-definitions';
 import { InitialStepStateGetter, VMSettings } from './types';
-
-export const vmSettingsOrder = {
-  [VMSettingsField.PROVIDER]: 0,
-  [VMSettingsField.USER_TEMPLATE]: 1,
-  [VMSettingsField.PROVISION_SOURCE_TYPE]: 2,
-  [VMSettingsField.CONTAINER_IMAGE]: 3,
-  [VMSettingsField.IMAGE_URL]: 4,
-  [VMSettingsField.OPERATING_SYSTEM]: 5,
-  [VMSettingsField.FLAVOR]: 6,
-  [VMSettingsField.MEMORY]: 7,
-  [VMSettingsField.CPU]: 8,
-  [VMSettingsField.WORKLOAD_PROFILE]: 9,
-  [VMSettingsField.NAME]: 10,
-  [VMSettingsField.DESCRIPTION]: 11,
-  [VMSettingsField.START_VM]: 12,
-};
+import { CUSTOM_FLAVOR } from '../../../../constants/vm';
 
 export const getInitialVmSettings = (data: CommonData): VMSettings => {
   const {
-    data: { isCreateTemplate, isProviderImport },
+    data: { isCreateTemplate, isProviderImport, userTemplateName },
   } = data;
 
   const hiddenByProvider = asHidden(isProviderImport, VMWizardProps.isProviderImport);
@@ -31,10 +15,7 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
     ? hiddenByProvider
     : asHidden(isCreateTemplate, VMWizardProps.isCreateTemplate);
 
-  const provisionSources = (isProviderImport
-    ? [ProvisionSource.IMPORT]
-    : [ProvisionSource.PXE, ProvisionSource.URL, ProvisionSource.CONTAINER, ProvisionSource.DISK]
-  ).map((source) => source.getValue());
+  const isVM = !isCreateTemplate && !isProviderImport;
 
   const fields = {
     [VMSettingsField.NAME]: {
@@ -44,17 +25,21 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
     [VMSettingsField.DESCRIPTION]: {},
     [VMSettingsField.USER_TEMPLATE]: {
       isHidden: hiddenByProviderOrTemplate,
-    },
-    [VMSettingsField.PROVIDER]: {
-      isRequired: asRequired(isProviderImport),
-      isHidden: asHidden(!isProviderImport),
-      providers: getProviders().map((provider) => provider.name),
+      isDisabled: asDisabled(!!userTemplateName, VMWizardProps.userTemplateName),
+      initialized: !(isVM && userTemplateName),
+      value: userTemplateName || undefined,
     },
     [VMSettingsField.PROVISION_SOURCE_TYPE]: {
-      value: isProviderImport ? ProvisionSource.IMPORT.getValue() : undefined,
       isHidden: hiddenByProvider,
-      isRequired: asRequired(true),
-      sources: OrderedSet(provisionSources),
+      isRequired: asRequired(!isProviderImport),
+      sources: OrderedSet(
+        [
+          ProvisionSource.PXE,
+          ProvisionSource.URL,
+          ProvisionSource.CONTAINER,
+          ProvisionSource.DISK,
+        ].map((source) => source.getValue()),
+      ),
     },
     [VMSettingsField.CONTAINER_IMAGE]: {
       isHidden: hiddenByProvider,
@@ -69,8 +54,11 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
     },
     [VMSettingsField.FLAVOR]: {
       isRequired: asRequired(true),
+      value: CUSTOM_FLAVOR,
+    },
+    [VMSettingsField.MEMORY]: {
+      binaryUnitValidation: true,
     },
-    [VMSettingsField.MEMORY]: {},
     [VMSettingsField.CPU]: {},
     [VMSettingsField.WORKLOAD_PROFILE]: {
       isRequired: asRequired(true),
@@ -79,12 +67,6 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
       value: false,
       isHidden: hiddenByProviderOrTemplate,
     },
-    [VMSettingsField.PROVIDERS_DATA]: {
-      ...getProviders().reduce((allProviders, provider) => {
-        allProviders[provider.name] = provider.getInitialState();
-        return allProviders;
-      }, {}),
-    },
   };
 
   Object.keys(fields).forEach((k) => {
@@ -99,4 +81,8 @@ export const getVmSettingsInitialState: InitialStepStateGetter = (data) => ({
   hasAllRequiredFilled: false,
   isValid: false,
   isLocked: false,
+  isHidden: data.data.isProviderImport && data.data.isSimpleView,
+  isCreateDisabled: false,
+  isUpdateDisabled: false,
+  isDeleteDisabled: false,
 });
