@@ -11,15 +11,19 @@ import {
   Title,
 } from '@patternfly/react-core';
 import { PlusCircleIcon } from '@patternfly/react-icons';
-import { iGetCreateVMWizardTabs } from '../../selectors/immutable/selectors';
-import { isStepLocked } from '../../selectors/immutable/wizard-selectors';
-import { VMWizardNetworkWithWrappers, VMWizardTab } from '../../types';
+import {
+  hasStepCreateDisabled,
+  hasStepDeleteDisabled,
+  hasStepUpdateDisabled,
+  isStepLocked,
+} from '../../selectors/immutable/wizard-selectors';
+import { VMWizardNetwork, VMWizardTab } from '../../types';
 import { VMNicsTable } from '../../../vm-nics/vm-nics';
 import { nicTableColumnClasses } from '../../../vm-nics/utils';
 import { vmWizardActions } from '../../redux/actions';
 import { ActionType } from '../../redux/types';
 import { iGetProvisionSource } from '../../selectors/immutable/vm-settings';
-import { getNetworksWithWrappers } from '../../selectors/selectors';
+import { getNetworks } from '../../selectors/selectors';
 import { wrapWithProgress } from '../../../../utils/utils';
 import { ProvisionSource } from '../../../../constants/vm/provision-source';
 import { DeviceType } from '../../../../constants/vm';
@@ -27,19 +31,22 @@ import { vmWizardNicModalEnhanced } from './vm-wizard-nic-modal-enhanced';
 import { VMWizardNicRow } from './vm-wizard-nic-row';
 import { VMWizardNetworkBundle } from './types';
 import { NetworkBootSource } from './network-boot-source';
+import { ADD_NETWORK_INTERFACE } from '../../../../utils/strings';
+import { NetworkWrapper } from '../../../../k8s/wrapper/vm/network-wrapper';
+import { NetworkInterfaceWrapper } from '../../../../k8s/wrapper/vm/network-interface-wrapper';
 
 import './networking-tab.scss';
-import { ADD_NETWORK_INTERFACE } from '../../../../utils/strings';
 
-const getNicsData = (networks: VMWizardNetworkWithWrappers[]): VMWizardNetworkBundle[] =>
+const getNicsData = (networks: VMWizardNetwork[]): VMWizardNetworkBundle[] =>
   networks.map((wizardNetworkData) => {
-    const { networkInterfaceWrapper, networkWrapper } = wizardNetworkData;
+    const { networkInterface, network } = wizardNetworkData;
+    const networkInterfaceWrapper = new NetworkInterfaceWrapper(networkInterface);
     return {
       wizardNetworkData,
       // for sorting
       name: networkInterfaceWrapper.getName(),
       model: networkInterfaceWrapper.getReadableModel(),
-      networkName: networkWrapper.getReadableName(),
+      networkName: new NetworkWrapper(network).getReadableName(),
       interfaceType: networkInterfaceWrapper.getTypeValue(),
       macAddress: networkInterfaceWrapper.getMACAddress(),
     };
@@ -53,6 +60,9 @@ const NetworkingTabComponent: React.FC<NetworkingTabComponentProps> = ({
   removeNIC,
   onBootOrderChanged,
   networks,
+  isCreateDisabled,
+  isUpdateDisabled,
+  isDeleteDisabled,
 }) => {
   const showNetworks = networks.length > 0 || isBootNICRequired;
 
@@ -67,7 +77,7 @@ const NetworkingTabComponent: React.FC<NetworkingTabComponentProps> = ({
           wizardReduxID,
         }).result,
       ),
-    isDisabled: isLocked,
+    isDisabled: isLocked || isCreateDisabled,
   };
 
   return (
@@ -91,7 +101,14 @@ const NetworkingTabComponent: React.FC<NetworkingTabComponentProps> = ({
           <VMNicsTable
             columnClasses={nicTableColumnClasses}
             data={getNicsData(networks)}
-            customData={{ isDisabled: isLocked, withProgress, removeNIC, wizardReduxID }}
+            customData={{
+              isDisabled: isLocked,
+              isDeleteDisabled,
+              isUpdateDisabled,
+              withProgress,
+              removeNIC,
+              wizardReduxID,
+            }}
             row={VMWizardNicRow}
           />
           {isBootNICRequired && (
@@ -122,22 +139,25 @@ const NetworkingTabComponent: React.FC<NetworkingTabComponentProps> = ({
 
 type NetworkingTabComponentProps = {
   isLocked: boolean;
+  isCreateDisabled: boolean;
+  isUpdateDisabled: boolean;
+  isDeleteDisabled: boolean;
   isBootNICRequired: boolean;
   wizardReduxID: string;
-  networks: VMWizardNetworkWithWrappers[];
+  networks: VMWizardNetwork[];
   removeNIC: (id: string) => void;
   setTabLocked: (isLocked: boolean) => void;
   onBootOrderChanged: (deviceID: string, bootOrder: number) => void;
 };
 
-const stateToProps = (state, { wizardReduxID }) => {
-  const stepData = iGetCreateVMWizardTabs(state, wizardReduxID);
-  return {
-    isLocked: isStepLocked(stepData, VMWizardTab.NETWORKING),
-    networks: getNetworksWithWrappers(state, wizardReduxID),
-    isBootNICRequired: iGetProvisionSource(state, wizardReduxID) === ProvisionSource.PXE,
-  };
-};
+const stateToProps = (state, { wizardReduxID }) => ({
+  isLocked: isStepLocked(state, wizardReduxID, VMWizardTab.NETWORKING),
+  isCreateDisabled: hasStepCreateDisabled(state, wizardReduxID, VMWizardTab.NETWORKING),
+  isUpdateDisabled: hasStepUpdateDisabled(state, wizardReduxID, VMWizardTab.NETWORKING),
+  isDeleteDisabled: hasStepDeleteDisabled(state, wizardReduxID, VMWizardTab.NETWORKING),
+  networks: getNetworks(state, wizardReduxID),
+  isBootNICRequired: iGetProvisionSource(state, wizardReduxID) === ProvisionSource.PXE,
+});
 
 const dispatchToProps = (dispatch, { wizardReduxID }) => ({
   setTabLocked: (isLocked) => {
