@@ -5,13 +5,13 @@ import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboa
 import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
 import HealthBody from '@console/shared/src/components/dashboard/status-card/HealthBody';
 import { DashboardItemProps } from '@console/internal/components/dashboard/with-dashboard-resources';
-import { VMStatus } from '../../vm-status';
+import { VMStatus } from '../../vm-status/vm-status';
 import { VMDashboardContext } from '../../vms/vm-dashboard-context';
 import { VMAlerts } from './vm-alerts';
 
 export const VMStatusCard: React.FC<VMStatusCardProps> = () => {
   const vmDashboardContext = React.useContext(VMDashboardContext);
-  const { vm, vmi, pods, migrations } = vmDashboardContext;
+  const { vm, vmi, vmStatusBundle } = vmDashboardContext;
 
   return (
     <DashboardCard gradient>
@@ -20,9 +20,9 @@ export const VMStatusCard: React.FC<VMStatusCardProps> = () => {
       </DashboardCardHeader>
       <DashboardCardBody>
         <HealthBody>
-          <VMStatus vm={vm} vmi={vmi} pods={pods} migrations={migrations} />
+          <VMStatus vm={vm} vmi={vmi} vmStatusBundle={vmStatusBundle} />
         </HealthBody>
-        <VMAlerts vm={vm} vmi={vmi} />
+        <VMAlerts vmi={vmi} />
       </DashboardCardBody>
     </DashboardCard>
   );
