@@ -2,11 +2,10 @@ import * as React from 'react';
 import { connect } from 'react-redux';
 import { Firehose, FirehoseResource, FirehoseResult } from '@console/internal/components/utils';
 import { createModalLauncher, ModalComponentProps } from '@console/internal/components/factory';
-import { k8sPatch, K8sResourceKind, referenceForModel } from '@console/internal/module/k8s';
+import { k8sPatch, referenceForModel } from '@console/internal/module/k8s';
 import { NetworkAttachmentDefinitionModel } from '@console/network-attachment-definition-plugin';
 import { getName, getNamespace } from '@console/shared';
 import { getLoadedData } from '../../../utils';
-import { NetworkType } from '../../../constants/vm';
 import { getInterfaces, getUsedNetworks, asVM, getVMLikeModel } from '../../../selectors/vm';
 import { NetworkInterfaceWrapper } from '../../../k8s/wrapper/vm/network-interface-wrapper';
 import { VMLikeEntityKind } from '../../../types/vmLike';
@@ -21,8 +20,8 @@ const NICModalFirehoseComponent: React.FC<NICModalFirehoseComponentProps> = (pro
   const vmLikeFinal = getLoadedData(vmLikeEntityLoading, vmLikeEntity); // default old snapshot before loading a new one
   const vm = asVM(vmLikeFinal);
 
-  const nicWrapper = nic ? NetworkInterfaceWrapper.initialize(nic) : NetworkInterfaceWrapper.EMPTY;
-  const networkWrapper = network ? NetworkWrapper.initialize(network) : NetworkWrapper.EMPTY;
+  const nicWrapper = new NetworkInterfaceWrapper(nic);
+  const networkWrapper = new NetworkWrapper(network);
 
   const usedNetworksChoices = getUsedNetworks(vm);
 
@@ -32,30 +31,24 @@ const NICModalFirehoseComponent: React.FC<NICModalFirehoseComponentProps> = (pro
       .filter((n) => n && n !== nicWrapper.getName()),
   );
 
-  const usedMultusNetworkNames: Set<string> = new Set(
-    usedNetworksChoices
-      .filter(
-        (usedNetwork) =>
-          usedNetwork.getType() === NetworkType.MULTUS &&
-          usedNetwork.getMultusNetworkName() !== networkWrapper.getMultusNetworkName(),
-      )
-      .map((usedNetwork) => usedNetwork.getMultusNetworkName()),
-  );
-
   const allowPodNetwork =
     networkWrapper.isPodNetwork() ||
     !usedNetworksChoices.find((usedNetwork) => usedNetwork.isPodNetwork());
 
-  const onSubmit = (resultNetworkInterfaceWrapper, resultNetworkWrapper) =>
+  const onSubmit = (
+    resultNetworkInterfaceWrapper: NetworkInterfaceWrapper,
+    resultNetworkWrapper: NetworkWrapper,
+  ) =>
     k8sPatch(
       getVMLikeModel(vmLikeEntity),
       vmLikeEntity,
       getUpdateNICPatches(vmLikeEntity, {
-        nic: NetworkInterfaceWrapper.mergeWrappers(
-          nicWrapper,
-          resultNetworkInterfaceWrapper,
-        ).asResource(),
-        network: NetworkWrapper.mergeWrappers(networkWrapper, resultNetworkWrapper).asResource(),
+        nic: new NetworkInterfaceWrapper(nicWrapper, true)
+          .mergeWith(resultNetworkInterfaceWrapper)
+          .asResource(),
+        network: new NetworkWrapper(networkWrapper, true)
+          .mergeWith(resultNetworkWrapper)
+          .asResource(),
         oldNICName: nicWrapper.getName(),
         oldNetworkName: networkWrapper.getName(),
       }),
@@ -65,10 +58,9 @@ const NICModalFirehoseComponent: React.FC<NICModalFirehoseComponentProps> = (pro
     <NICModal
       {...restProps}
       usedInterfacesNames={usedInterfacesNames}
-      usedMultusNetworkNames={usedMultusNetworkNames}
       allowPodNetwork={allowPodNetwork}
-      nic={nicWrapper}
-      network={networkWrapper}
+      nic={new NetworkInterfaceWrapper(nicWrapper, true)}
+      network={new NetworkWrapper(networkWrapper, true)}
       onSubmit={onSubmit}
     />
   );
@@ -77,7 +69,8 @@ const NICModalFirehoseComponent: React.FC<NICModalFirehoseComponentProps> = (pro
 type NICModalFirehoseComponentProps = ModalComponentProps & {
   nic?: any;
   network?: any;
-  nads?: FirehoseResult<K8sResourceKind[]>;
+  isEditing?: boolean;
+  nads?: FirehoseResult;
   vmLikeEntityLoading?: FirehoseResult<VMLikeEntityKind>;
   vmLikeEntity: VMLikeEntityKind;
 };
@@ -119,6 +112,7 @@ type NICModalFirehoseProps = ModalComponentProps & {
   vmLikeEntity: VMLikeEntityKind;
   nic?: any;
   network?: any;
+  isEditing?: boolean;
   hasNADs: boolean;
 };
 
