@@ -5,14 +5,8 @@ import {
   HandlePromiseProps,
   withHandlePromise,
 } from '@console/internal/components/utils';
-import {
-  createModalLauncher,
-  ModalBody,
-  ModalComponentProps,
-  ModalTitle,
-} from '@console/internal/components/factory';
-import { K8sResourceKind } from '@console/internal/module/k8s';
-import { ValidationErrorType } from '@console/shared';
+import { ModalBody, ModalComponentProps, ModalTitle } from '@console/internal/components/factory';
+import { getName, ValidationErrorType } from '@console/shared';
 import { NetworkAttachmentDefinitionModel } from '@console/network-attachment-definition-plugin';
 import { getLoadedData, getLoadError, isLoaded, prefixedID } from '../../../utils';
 import { validateNIC } from '../../../utils/validations/vm';
@@ -24,25 +18,41 @@ import {
   FormSelectPlaceholderOption,
 } from '../../form/form-select-placeholder-option';
 import {
-  NetworkInterfaceType,
   NetworkInterfaceModel,
+  NetworkInterfaceType,
   NetworkType,
 } from '../../../constants/vm/network';
-import { getNetworkChoices } from '../../../selectors/nad';
 import { NetworkInterfaceWrapper } from '../../../k8s/wrapper/vm/network-interface-wrapper';
 import { NetworkWrapper } from '../../../k8s/wrapper/vm/network-wrapper';
 import { ADD, EDIT, getDialogUIError, getSequenceName, SAVE } from '../../../utils/strings';
 import { ModalFooter } from '../modal/modal-footer';
 import { useShowErrorToggler } from '../../../hooks/use-show-error-toggler';
+import { UINetworkEditConfig } from '../../../types/ui/nic';
+import { isFieldDisabled } from '../../../utils/ui/edit-config';
+import { K8sResourceKind } from '@console/internal/module/k8s';
+
+const getNetworkChoices = (nads: K8sResourceKind[], allowPodNetwork): NetworkWrapper[] => {
+  const networkChoices = nads.map((nad) => {
+    const networkName = getName(nad);
+    return new NetworkWrapper().setType(NetworkType.MULTUS, {
+      networkName,
+    });
+  });
+
+  if (allowPodNetwork) {
+    networkChoices.push(new NetworkWrapper().setType(NetworkType.POD));
+  }
+  return networkChoices;
+};
 
 export type NetworkProps = {
   id: string;
   isDisabled: boolean;
-  nads?: FirehoseResult<K8sResourceKind[]>;
-  usedMultusNetworkNames: Set<string>;
+  nads?: FirehoseResult;
   allowPodNetwork: boolean;
   network?: NetworkWrapper;
-  onChange: (networkChoice: NetworkWrapper) => void;
+  onChange: (networkChoice: NetworkType, network: string) => void;
+  acceptEmptyValues?: boolean;
 };
 
 export const Network: React.FC<NetworkProps> = ({
@@ -51,16 +61,14 @@ export const Network: React.FC<NetworkProps> = ({
   network,
   onChange,
   nads,
-  usedMultusNetworkNames,
   allowPodNetwork,
+  acceptEmptyValues,
 }) => {
   const nadsLoading = !isLoaded(nads);
   const nadsLoadError = getLoadError(nads, NetworkAttachmentDefinitionModel);
-  const networkChoices = getNetworkChoices(
-    getLoadedData(nads, []),
-    usedMultusNetworkNames,
-    allowPodNetwork,
-  ).filter((n) => n.getType().isSupported());
+  const networkChoices = getNetworkChoices(getLoadedData(nads, []), allowPodNetwork).filter((n) =>
+    n.getType().isSupported(),
+  );
 
   return (
     <FormRow
@@ -74,20 +82,17 @@ export const Network: React.FC<NetworkProps> = ({
       <FormSelect
         onChange={(net, event) => {
           const target = event.target as HTMLSelectElement;
-          const newNetworkType = target[target.selectedIndex].getAttribute('data-network-type');
-          onChange(
-            NetworkWrapper.initializeFromSimpleData({
-              type: NetworkType.fromString(newNetworkType),
-              multusNetworkName: net,
-            }),
+          const newNetworkType = NetworkType.fromString(
+            target[target.selectedIndex].getAttribute('data-network-type'),
           );
+          onChange(newNetworkType, newNetworkType === NetworkType.MULTUS ? net : undefined);
         }}
-        value={asFormSelectValue(network && network.getReadableName())}
+        value={asFormSelectValue(network?.getReadableName())}
         id={id}
         isDisabled={isDisabled || nadsLoading || nadsLoadError}
       >
         <FormSelectPlaceholderOption
-          isDisabled
+          isDisabled={!acceptEmptyValues}
           placeholder={
             networkChoices.length === 0
               ? '--- Network Definitions not available ---'
@@ -115,8 +120,9 @@ export const Network: React.FC<NetworkProps> = ({
 export const NICModal = withHandlePromise((props: NICModalProps) => {
   const {
     nads,
+    showInitialValidation,
+    isEditing,
     usedInterfacesNames,
-    usedMultusNetworkNames,
     allowPodNetwork,
     onSubmit,
     inProgress,
@@ -124,11 +130,14 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
     handlePromise,
     close,
     cancel,
+    editConfig,
   } = props;
+  const isDisabled = (fieldName: string, disabled?: boolean) =>
+    inProgress || disabled || isFieldDisabled(editConfig, fieldName);
+
   const asId = prefixedID.bind(null, 'nic');
-  const nic = props.nic || NetworkInterfaceWrapper.EMPTY;
-  const network = props.network || NetworkWrapper.EMPTY;
-  const isEditing = nic !== NetworkInterfaceWrapper.EMPTY;
+  const nic = props.nic || new NetworkInterfaceWrapper();
+  const network = props.network || new NetworkWrapper();
 
   const [name, setName] = React.useState<string>(
     nic.getName() || getSequenceName('nic', usedInterfacesNames),
@@ -136,34 +145,53 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
   const [model, setModel] = React.useState<NetworkInterfaceModel>(
     nic.getModel() || (isEditing ? null : NetworkInterfaceModel.VIRTIO),
   );
-  const [resultNetwork, setResultNetwork] = React.useState<NetworkWrapper>(network);
+  const [networkType, setNetworkType] = React.useState<NetworkType>(network.getType());
+  const [multusNetworkName, setMultusNetworkName] = React.useState<string>(
+    network.getMultusNetworkName(),
+  );
   const [interfaceType, setInterfaceType] = React.useState<NetworkInterfaceType>(nic.getType());
   const [macAddress, setMacAddress] = React.useState<string>(nic.getMACAddress() || '');
 
-  const resultNIC = NetworkInterfaceWrapper.initializeFromSimpleData({
-    name,
-    model,
-    interfaceType,
-    macAddress,
-  });
+  const resultNIC = new NetworkInterfaceWrapper()
+    .init({
+      name,
+      model,
+      macAddress,
+    })
+    .setType(interfaceType);
+
+  const resultNetwork = new NetworkWrapper()
+    .init({
+      name,
+    })
+    .setType(networkType, { networkName: multusNetworkName });
 
   const {
     validations: { name: nameValidation, macAddress: macAddressValidation },
     isValid,
     hasAllRequiredFilled,
-  } = validateNIC(resultNIC, resultNetwork, { usedInterfacesNames });
+  } = validateNIC(resultNIC, resultNetwork, {
+    usedInterfacesNames,
+    acceptEmptyNetwork: editConfig?.acceptEmptyValuesOverride?.network,
+  });
 
-  const [showUIError, setShowUIError] = useShowErrorToggler(false, isValid, isValid);
+  const [showUIError, setShowUIError] = useShowErrorToggler(
+    !!showInitialValidation,
+    isValid,
+    isValid,
+  );
 
-  const onNetworkChoiceChange = (newNetworkChoice: NetworkWrapper) => {
-    if (newNetworkChoice.isPodNetwork()) {
+  const onNetworkChoiceChange = (newType: NetworkType, newMultusNetworkName) => {
+    if (newType === NetworkType.POD) {
       setMacAddress('');
     }
 
-    if (!interfaceType || !newNetworkChoice.getType().allowsInterfaceType(interfaceType)) {
-      setInterfaceType(newNetworkChoice.getType().getDefaultInterfaceType());
+    if (!interfaceType || (newType && !newType.allowsInterfaceType(interfaceType))) {
+      setInterfaceType(newType.getDefaultInterfaceType());
     }
-    setResultNetwork(newNetworkChoice);
+
+    setNetworkType(newType);
+    setMultusNetworkName(newMultusNetworkName);
   };
 
   const submit = (e) => {
@@ -171,15 +199,7 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
 
     if (isValid) {
       // eslint-disable-next-line promise/catch-or-return
-      handlePromise(
-        onSubmit(
-          resultNIC,
-          NetworkWrapper.mergeWrappers(
-            resultNetwork,
-            NetworkWrapper.initializeFromSimpleData({ name: resultNIC.getName() }),
-          ),
-        ),
-      ).then(close);
+      handlePromise(onSubmit(resultNIC, resultNetwork)).then(close);
     } else {
       setShowUIError(true);
     }
@@ -199,7 +219,7 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
           >
             <TextInput
               isValid={!isValidationError(nameValidation)}
-              isDisabled={!usedInterfacesNames || inProgress}
+              isDisabled={isDisabled('name', !usedInterfacesNames)}
               isRequired
               id={asId('name')}
               value={name}
@@ -213,7 +233,7 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
               }
               value={asFormSelectValue(model)}
               id={asId('model')}
-              isDisabled={inProgress}
+              isDisabled={isDisabled('model')}
             >
               <FormSelectPlaceholderOption isDisabled placeholder="--- Select Model ---" />
               {NetworkInterfaceModel.getAll().map((ifaceModel) => {
@@ -229,19 +249,19 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
           </FormRow>
           <Network
             id={asId('network')}
-            isDisabled={inProgress}
+            isDisabled={isDisabled('network')}
             network={resultNetwork}
             onChange={onNetworkChoiceChange}
             nads={nads}
-            usedMultusNetworkNames={usedMultusNetworkNames}
             allowPodNetwork={allowPodNetwork}
+            acceptEmptyValues={editConfig?.acceptEmptyValuesOverride?.network}
           />
           <FormRow title="Type" fieldId={asId('type')} isRequired>
             <FormSelect
               onChange={(iType) => setInterfaceType(NetworkInterfaceType.fromString(iType))}
               value={asFormSelectValue(interfaceType)}
               id={asId('type')}
-              isDisabled={inProgress}
+              isDisabled={isDisabled('type')}
             >
               <FormSelectPlaceholderOption isDisabled placeholder="--- Select Type ---" />
               {(resultNetwork.getType()
@@ -263,7 +283,7 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
           >
             <TextInput
               isValid={!isValidationError(macAddressValidation)}
-              isDisabled={inProgress || resultNetwork.isPodNetwork()}
+              isDisabled={isDisabled('macAddress', resultNetwork.isPodNetwork())}
               id={asId('mac-address')}
               value={macAddress}
               onChange={(v) => setMacAddress(v)}
@@ -274,7 +294,9 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
       <ModalFooter
         id="nic"
         submitButtonText={isEditing ? SAVE : ADD}
-        errorMessage={errorMessage || (showUIError ? getDialogUIError(hasAllRequiredFilled) : null)}
+        errorMessage={
+          errorMessage || (!isValid && showUIError ? getDialogUIError(hasAllRequiredFilled) : null)
+        }
         isDisabled={inProgress}
         isSimpleError={showUIError}
         onSubmit={submit}
@@ -288,14 +310,14 @@ export const NICModal = withHandlePromise((props: NICModalProps) => {
 });
 
 export type NICModalProps = {
+  showInitialValidation?: boolean;
+  isEditing?: boolean;
   nic?: NetworkInterfaceWrapper;
   network?: NetworkWrapper;
   onSubmit: (networkInterface: NetworkInterfaceWrapper, network: NetworkWrapper) => Promise<any>;
-  nads?: FirehoseResult<K8sResourceKind[]>;
+  nads?: FirehoseResult;
   usedInterfacesNames: Set<string>;
-  usedMultusNetworkNames: Set<string>;
   allowPodNetwork: boolean;
+  editConfig?: UINetworkEditConfig;
 } & ModalComponentProps &
   HandlePromiseProps;
-
-export const nicModal = createModalLauncher(NICModal);
