@@ -1,8 +1,8 @@
 /* eslint-disable lines-between-class-members */
-import { ValueEnum } from '../../value-enum';
+import { ObjectEnum } from '../../object-enum';
 import { NetworkInterfaceType } from './network-interface-type';
 
-export class NetworkType extends ValueEnum<string> {
+export class NetworkType extends ObjectEnum<string> {
   static readonly MULTUS = new NetworkType('multus', NetworkInterfaceType.BRIDGE, [
     NetworkInterfaceType.BRIDGE,
     NetworkInterfaceType.SRIOV,
@@ -19,7 +19,9 @@ export class NetworkType extends ValueEnum<string> {
     false,
   ); // not possible to select in NIC modal
 
-  private static ALL = Object.freeze(ValueEnum.getAllClassEnumProperties<NetworkType>(NetworkType));
+  private static ALL = Object.freeze(
+    ObjectEnum.getAllClassEnumProperties<NetworkType>(NetworkType),
+  );
 
   private static stringMapper = NetworkType.ALL.reduce(
     (accumulator, networkType: NetworkType) => ({
@@ -33,9 +35,6 @@ export class NetworkType extends ValueEnum<string> {
 
   static fromString = (model: string): NetworkType => NetworkType.stringMapper[model];
 
-  static fromSerialized = (networkType: { value: string }): NetworkType =>
-    NetworkType.fromString(networkType && networkType.value);
-
   private readonly defaultInterfaceType: NetworkInterfaceType;
   private readonly allowedInterfaceTypes: Readonly<NetworkInterfaceType[]>;
   private readonly allowedInterfaceTypesSet: Set<NetworkInterfaceType>;
