@@ -1,7 +1,7 @@
 /* eslint-disable lines-between-class-members */
-import { ValueEnum } from '../../value-enum';
+import { ObjectEnum } from '../../object-enum';
 
-export class VolumeType extends ValueEnum<string> {
+export class VolumeType extends ObjectEnum<string> {
   static readonly CLOUD_INIT_CONFIG_DRIVE = new VolumeType('cloudInitConfigDrive');
   static readonly CLOUD_INIT_NO_CLOUD = new VolumeType('cloudInitNoCloud');
   static readonly CONFIG_MAP = new VolumeType('configMap');
@@ -14,7 +14,7 @@ export class VolumeType extends ValueEnum<string> {
   static readonly SERVICE_ACCOUNT = new VolumeType('serviceAccount');
 
   private static readonly ALL = Object.freeze(
-    ValueEnum.getAllClassEnumProperties<VolumeType>(VolumeType),
+    ObjectEnum.getAllClassEnumProperties<VolumeType>(VolumeType),
   );
 
   private static readonly stringMapper = VolumeType.ALL.reduce(
@@ -27,8 +27,5 @@ export class VolumeType extends ValueEnum<string> {
 
   static getAll = () => VolumeType.ALL;
 
-  static fromSerialized = (volumeType: { value: string }): VolumeType =>
-    VolumeType.fromString(volumeType && volumeType.value);
-
   static fromString = (model: string): VolumeType => VolumeType.stringMapper[model];
 }
