@@ -17,7 +17,12 @@ import {
 } from '@console/shared';
 import { confirmModal, deleteModal } from '@console/internal/components/modals';
 import { MachineModel, MachineSetModel } from '@console/internal/models';
-import { findNodeMaintenance, getHostMachine, getHostPowerStatus } from '../../selectors';
+import {
+  findNodeMaintenance,
+  getHostMachine,
+  getHostPowerStatus,
+  isHostScheduledForRestart,
+} from '../../selectors';
 import { BareMetalHostModel, NodeMaintenanceModel } from '../../models';
 import { getHostStatus } from '../../status/host-status';
 import {
@@ -39,6 +44,8 @@ import { DELETE_MACHINE_ANNOTATION } from '../../constants/machine';
 import { deprovision } from '../../k8s/requests/bare-metal-host';
 import { getMachineMachineSetOwner } from '../../selectors/machine';
 import { findMachineSet } from '../../selectors/machine-set';
+import { restartHostModal } from '../modals/RestartHostModal';
+import { StatusProps } from '../types';
 
 type ActionArgs = {
   machine?: MachineKind;
@@ -46,7 +53,7 @@ type ActionArgs = {
   nodeName?: string;
   nodeMaintenance?: K8sResourceKind;
   hasNodeMaintenanceCapability?: boolean;
-  status: string;
+  status: StatusProps;
 };
 
 export const Edit = (kindObj: K8sKind, host: BareMetalHostKind): KebabOption => ({
@@ -60,7 +67,7 @@ export const SetNodeMaintenance = (
   { hasNodeMaintenanceCapability, nodeMaintenance, nodeName }: ActionArgs,
 ): KebabOption => ({
   hidden: !nodeName || !hasNodeMaintenanceCapability || !!nodeMaintenance,
-  label: 'Start Node Maintenance',
+  label: 'Start Maintenance',
   callback: () => startNodeMaintenanceModal({ nodeName }),
 });
 
@@ -70,7 +77,7 @@ export const RemoveNodeMaintenance = (
   { hasNodeMaintenanceCapability, nodeMaintenance, nodeName }: ActionArgs,
 ): KebabOption => ({
   hidden: !nodeName || !hasNodeMaintenanceCapability || !nodeMaintenance,
-  label: 'Stop Node Maintenance',
+  label: 'Stop Maintenance',
   callback: () => stopNodeMaintenanceModal(nodeMaintenance),
   accessReview: nodeMaintenance && asAccessReview(NodeMaintenanceModel, nodeMaintenance, 'delete'),
 });
@@ -97,6 +104,10 @@ export const Deprovision = (
   const title = 'Deprovision';
   return {
     hidden:
+      [HOST_POWER_STATUS_POWERED_OFF, HOST_POWER_STATUS_POWERING_OFF].includes(
+        getHostPowerStatus(host),
+      ) ||
+      isHostScheduledForRestart(host) ||
       !machine ||
       !!getAnnotations(machine, {})[DELETE_MACHINE_ANNOTATION] ||
       (getMachineMachineSetOwner(machine) && !machineSet),
@@ -119,13 +130,23 @@ export const Deprovision = (
 export const PowerOff = (
   kindObj: K8sKind,
   host: BareMetalHostKind,
-  { hasNodeMaintenanceCapability, nodeName, status }: ActionArgs,
+  { nodeName, status }: ActionArgs,
 ) => ({
   hidden: [HOST_POWER_STATUS_POWERED_OFF, HOST_POWER_STATUS_POWERING_OFF].includes(
     getHostPowerStatus(host),
   ),
   label: 'Power Off',
-  callback: () => powerOffHostModal({ hasNodeMaintenanceCapability, host, nodeName, status }),
+  callback: () => powerOffHostModal({ host, nodeName, status }),
+  accessReview: host && asAccessReview(BareMetalHostModel, host, 'update'),
+});
+
+export const Restart = (kindObj: K8sKind, host: BareMetalHostKind, { nodeName }: ActionArgs) => ({
+  hidden:
+    [HOST_POWER_STATUS_POWERED_OFF, HOST_POWER_STATUS_POWERING_OFF].includes(
+      getHostPowerStatus(host),
+    ) || isHostScheduledForRestart(host),
+  label: 'Restart',
+  callback: () => restartHostModal({ host, nodeName }),
   accessReview: host && asAccessReview(BareMetalHostModel, host, 'update'),
 });
 
@@ -142,7 +163,7 @@ export const Delete = (
       HOST_STATUS_AVAILABLE,
       HOST_STATUS_DISCOVERED,
       ...HOST_ERROR_STATES,
-    ].includes(status),
+    ].includes(status.status),
     label: title,
     callback: () =>
       deleteModal({
@@ -159,6 +180,7 @@ export const menuActions = [
   PowerOn,
   Deprovision,
   PowerOff,
+  Restart,
   Kebab.factory.ModifyLabels,
   Kebab.factory.ModifyAnnotations,
   Edit,
@@ -194,7 +216,7 @@ export const menuActionsCreator = (
       nodeName,
       machine,
       machineSet,
-      status: status.status,
+      status,
     });
   });
 };
