@@ -3,7 +3,6 @@ import { NodeKind, K8sResourceKind } from '@console/internal/module/k8s';
 import NodeDetailsConditions from '@console/app/src/components/nodes/NodeDetailsConditions';
 import NodeDetailsImages from '@console/app/src/components/nodes/NodeDetailsImages';
 import { getNodeMachineName, getName, createBasicLookup } from '@console/shared';
-import { bareMetalNodeStatus } from '../../status/baremetal-node-status';
 import { BareMetalHostKind } from '../../types';
 import { getNodeMaintenanceNodeName, getHostMachineName } from '../../selectors';
 import BareMetalNodeDetailsOverview from './BareMetalNodeDetailsOverview';
@@ -23,10 +22,9 @@ const BareMetalNodeDetails: React.FC<BareMetalNodeDetailsProps> = ({
   const hostsByMachineName = createBasicLookup(hosts, getHostMachineName);
   const host = hostsByMachineName[getNodeMachineName(node)];
   const nodeMaintenance = maintenancesByNodeName[getName(node)];
-  const status = bareMetalNodeStatus({ node, nodeMaintenance });
   return (
     <>
-      <BareMetalNodeDetailsOverview node={node} status={status} host={host} />
+      <BareMetalNodeDetailsOverview node={node} host={host} nodeMaintenance={nodeMaintenance} />
       <NodeDetailsConditions node={node} />
       <NodeDetailsImages node={node} />
     </>
