@@ -2,12 +2,12 @@ import { k8sGet, K8sResourceKind } from '@console/internal/module/k8s';
 import { InfrastructureModel } from '@console/internal/models';
 import { getInfrastructurePlatform } from '@console/shared/src/selectors/infrastructure';
 import { setFlag, handleError } from '@console/internal/actions/features';
-import { ActionFeatureFlagDetector } from '@console/plugin-sdk';
+import { FeatureDetector } from '@console/plugin-sdk';
 
 export const BAREMETAL_FLAG = 'BAREMETAL';
-export const CEPH_FLAG = 'CEPH';
+export const NODE_MAINTENANCE_FLAG = 'NODE_MAINTENANCE';
 
-export const detectBaremetalPlatform: ActionFeatureFlagDetector = (dispatch) =>
+export const detectBaremetalPlatform: FeatureDetector = (dispatch) =>
   k8sGet(InfrastructureModel, 'cluster').then(
     (infra: K8sResourceKind) =>
       dispatch(setFlag(BAREMETAL_FLAG, getInfrastructurePlatform(infra) === 'BareMetal')),
