@@ -12,13 +12,15 @@ import * as crudView from '@console/internal-integration-tests/views/crud.view';
 import * as catalogView from '@console/internal-integration-tests/views/catalog.view';
 import * as catalogPageView from '@console/internal-integration-tests/views/catalog-page.view';
 import * as sidenavView from '@console/internal-integration-tests/views/sidenav.view';
-import * as yamlView from '@console/internal-integration-tests/views/yaml.view';
 import * as operatorView from '../views/operator.view';
 import * as operatorHubView from '../views/operator-hub.view';
+import { click } from '@console/shared/src/test-utils/utils';
+import { NAME_FIELD_ID, formFieldIsPresent } from '../views/descriptors.view';
 
 describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)', () => {
   const prometheusResources = new Set(['StatefulSet', 'Pod']);
   const prometheusOperatorName = 'prometheus-operator';
+  const customProviderUID = 'providerType-console-e-2-e-operators';
 
   const catalogSource = {
     apiVersion: 'operators.coreos.com/v1alpha1',
@@ -72,7 +74,7 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
   it('displays subscription creation form for selected Operator', async () => {
     await catalogView.categoryTabsPresent();
     await catalogView.categoryTabs.get(0).click();
-    await catalogPageView.clickFilterCheckbox('providerType-custom');
+    await catalogPageView.clickFilterCheckbox(customProviderUID);
     await catalogPageView.catalogTileFor('Prometheus Operator').click();
     await browser.wait(until.visibilityOf(operatorHubView.operatorModal));
     await operatorHubView.operatorModalInstallBtn.click();
@@ -99,7 +101,7 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
     await crudView.isLoaded();
     await browser.get(`${appHost}/operatorhub/ns/${testName}`);
     await crudView.isLoaded();
-    await catalogPageView.clickFilterCheckbox('providerType-custom');
+    await catalogPageView.clickFilterCheckbox(customProviderUID);
     await catalogPageView.clickFilterCheckbox('installState-installed');
 
     expect(catalogPageView.catalogTileFor('Prometheus Operator').isDisplayed()).toBe(true);
@@ -113,11 +115,11 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
 
     await browser.wait(
       until.visibilityOf(operatorView.rowForOperator('Prometheus Operator')),
-      30000,
+      60000,
     );
   });
 
-  it('creates Prometheus Operator `Deployment`', async () => {
+  xit('creates Prometheus Operator `Deployment`', async () => {
     await browser.get(`${appHost}/k8s/ns/${testName}/deployments`);
     await crudView.isLoaded();
     await crudView.filterForName(prometheusOperatorName);
@@ -162,7 +164,7 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
     );
   });
 
-  it('displays YAML editor for creating a new `Prometheus` instance', async () => {
+  it('displays form editor for creating a new `Prometheus` instance', async () => {
     await browser.wait(until.visibilityOf(element(by.buttonText('Create New'))));
     await element(by.buttonText('Create New')).click();
     await browser.wait(until.visibilityOf($$('.pf-c-dropdown__menu').first()), 1000);
@@ -170,13 +172,13 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
       .first()
       .element(by.buttonText('Prometheus'))
       .click();
-    await yamlView.isLoaded();
+    await formFieldIsPresent(NAME_FIELD_ID);
 
     expect($('.co-create-operand__header').getText()).toContain('Create Prometheus');
   });
 
-  it('displays new `Prometheus` that was created from YAML editor', async () => {
-    await $('#save-changes').click();
+  it('displays new `Prometheus` that was created from form editor', async () => {
+    await $('button[type="submit"]').click();
     await crudView.isLoaded();
     await browser.wait(until.visibilityOf(operatorView.operandLink('example')));
 
@@ -202,11 +204,12 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
     expect(crudView.successMessage.getText()).toContain('example has been updated to version');
   });
 
-  it('displays Kubernetes objects associated with the `Prometheus` in its "Resources" section', async () => {
+  xit('displays Kubernetes objects associated with the `Prometheus` in its "Resources" section', async () => {
     await element(by.linkText('Resources')).click();
     await crudView.isLoaded();
 
     await crudView.rowFiltersPresent();
+    await click(crudView.rowFiltersButton);
     prometheusResources.forEach((kind) => {
       expect(crudView.rowFilterFor(kind).isDisplayed()).toBe(true);
     });
@@ -215,7 +218,7 @@ describe('Interacting with a `OwnNamespace` install mode Operator (Prometheus)',
   it('displays button to uninstall the Operator', async () => {
     await browser.get(`${appHost}/operatorhub/ns/${testName}`);
     await crudView.isLoaded();
-    await catalogPageView.clickFilterCheckbox('providerType-custom');
+    await catalogPageView.clickFilterCheckbox(customProviderUID);
     await catalogPageView.clickFilterCheckbox('installState-installed');
     await catalogPageView.catalogTileFor('Prometheus Operator').click();
     await operatorHubView.operatorModalIsLoaded();
