@@ -979,17 +979,13 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
                   href: referenceForProvidedAPI(desc),
                   name: ['Details', 'YAML', 'Subscription', 'Events'].includes(desc.displayName)
                     ? `${desc.displayName} Operand`
-                    : desc.displayName,
-                  component: React.memo(
-                    () => (
-                      <ProvidedAPIPage
-                        csv={obj}
-                        kind={referenceForProvidedAPI(desc)}
-                        namespace={obj.metadata.namespace}
-                      />
-                    ),
-                    _.isEqual,
-                  ),
+                    : desc.displayName || desc.kind,
+                  component: ProvidedAPIPage,
+                  pageData: {
+                    csv: obj,
+                    kind: referenceForProvidedAPI(desc),
+                    namespace: obj.metadata.namespace,
+                  },
                 },
               ]
             : acc,
