@@ -5,10 +5,10 @@ import { Button, Switch, Tooltip, Checkbox } from '@patternfly/react-core';
 import { EyeIcon, EyeSlashIcon, PencilAltIcon } from '@patternfly/react-icons';
 import { LoadingInline, ResourceLink, Selector } from '@console/internal/components/utils';
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
-import { k8sPatch } from '@console/internal/module/k8s';
+import { k8sPatch, k8sUpdate } from '@console/internal/module/k8s';
 import { YellowExclamationTriangleIcon } from '@console/shared';
 import { SecretValue } from '@console/internal/components/configmap-and-secret-data';
-import { CapabilityProps, DescriptorProps, SpecCapability } from '../types';
+import { CapabilityProps, DescriptorProps, SpecCapability, Error } from '../types';
 import { ResourceRequirementsModalLink } from './resource-requirements';
 import { EndpointList } from './endpoint';
 import { configureSizeModal } from './configure-size';
@@ -90,42 +90,66 @@ const BasicSelector: React.SFC<SpecCapabilityProps> = ({ value, capability }) =>
 );
 
 const BooleanSwitch: React.FC<SpecCapabilityProps> = (props) => {
+  const { model, obj, descriptor, onHandleError } = props;
   const convertedValue = !_.isNil(props.value) ? props.value : false;
   const [value, setValue] = React.useState(convertedValue);
   const [confirmed, setConfirmed] = React.useState(false);
+  const [errorMessage, setErrorMessage] = React.useState(null);
+
+  const errorCb = (err: Error): void => {
+    setConfirmed(false);
+    setValue(convertedValue);
+    setErrorMessage(err.message);
+    onHandleError(err.message);
+  };
 
-  const patchFor = (val: boolean) => [
-    { op: 'add', path: `/spec/${props.descriptor.path.replace('.', '/')}`, value: val },
-  ];
   const update = () => {
     setConfirmed(true);
-    return k8sPatch(props.model, props.obj, patchFor(value));
+    setErrorMessage(null);
+
+    if (_.has(obj, `spec.${descriptor.path}`)) {
+      const patchFor = (val: boolean) => [
+        { op: 'add', path: `/spec/${descriptor.path.replace(/\./g, '/')}`, value: val },
+      ];
+      return k8sPatch(model, obj, patchFor(value)).catch((err) => errorCb(err));
+    }
+
+    const newObj = _.cloneDeep(obj);
+    _.set(newObj, `spec.${descriptor.path}`, value);
+    return k8sUpdate(model, newObj).catch((err) => errorCb(err));
   };
 
   return (
-    <div className="co-spec-descriptor--switch">
-      <Switch
-        id={props.descriptor.path}
-        isChecked={value}
-        onChange={(val) => {
-          setValue(val);
-          setConfirmed(false);
-        }}
-        label="True"
-        labelOff="False"
-      />
-      &nbsp;&nbsp;
-      {value !== convertedValue && confirmed && <LoadingInline />}
-      {value !== convertedValue && !confirmed && (
-        <>
-          &nbsp;&nbsp;
-          <Button className="pf-m-link--align-left" type="button" variant="link" onClick={update}>
-            <YellowExclamationTriangleIcon className="co-icon-space-r pf-c-button-icon--plain" />
-            Confirm change
-          </Button>
-        </>
+    <>
+      <div className="co-spec-descriptor--switch">
+        <Switch
+          id={descriptor.path}
+          isChecked={value}
+          onChange={(val) => {
+            setValue(val);
+            setConfirmed(false);
+            setErrorMessage(null);
+            onHandleError(null);
+          }}
+          label="True"
+          labelOff="False"
+        />
+        &nbsp;&nbsp;
+        {value !== convertedValue && confirmed && <LoadingInline />}
+        {value !== convertedValue && !confirmed && (
+          <>
+            &nbsp;&nbsp;
+            <Button className="pf-m-link--align-left" type="button" variant="link" onClick={update}>
+              <YellowExclamationTriangleIcon className="co-icon-space-r pf-c-button-icon--plain" />
+              Confirm change
+            </Button>
+          </>
+        )}
+      </div>
+      {errorMessage && (
+        <div className="cos-error-title co-break-word">{errorMessage || 'An error occurred'}</div>
       )}
-    </div>
+    </>
   );
 };
 
@@ -174,20 +198,28 @@ const Secret: React.FC<SpecCapabilityProps> = (props) => {
 
   return (
     <>
-      <Button type="button" onClick={() => setReveal(!reveal)}>
-        {reveal ? (
-          <>
-            <EyeSlashIcon className="co-icon-space-r" />
-            Hide Values
-          </>
-        ) : (
-          <>
-            <EyeIcon className="co-icon-space-r" />
-            Reveal Values
-          </>
-        )}
-      </Button>
-      <SecretValue value={props.value} encoded={false} reveal={reveal} />
+      <div className="co-toggle-reveal-value">
+        <Button
+          type="button"
+          variant="link"
+          isInline
+          className="pf-m-link--align-right co-toggle-reveal-value__btn"
+          onClick={() => setReveal(!reveal)}
+        >
+          {reveal ? (
+            <>
+              <EyeSlashIcon className="co-icon-space-r" />
+              Hide Values
+            </>
+          ) : (
+            <>
+              <EyeIcon className="co-icon-space-r" />
+              Reveal Values
+            </>
+          )}
+        </Button>
+        <SecretValue value={props.value} encoded={false} reveal={reveal} />
+      </div>
     </>
   );
 };
@@ -225,7 +257,8 @@ const capabilityComponents = ImmutableMap<
   .set(SpecCapability.booleanSwitch, BooleanSwitch)
   .set(SpecCapability.password, Secret)
   .set(SpecCapability.updateStrategy, UpdateStrategy)
-  .set(SpecCapability.checkbox, CheckboxUIComponent);
+  .set(SpecCapability.checkbox, CheckboxUIComponent)
+  .set(SpecCapability.hidden, null);
 
 const capabilityFor = (specCapability: SpecCapability) => {
   if (_.isEmpty(specCapability)) {
@@ -245,7 +278,7 @@ const capabilityFor = (specCapability: SpecCapability) => {
  * individual components from this module.
  */
 export const SpecDescriptor = withFallback((props: DescriptorProps) => {
-  const { model, obj, descriptor, value, namespace } = props;
+  const { model, obj, descriptor, value, namespace, onHandleError } = props;
   const capability = _.get(descriptor, ['x-descriptors'], []).find(
     (c) =>
       !c.startsWith(SpecCapability.fieldGroup) &&
@@ -255,7 +288,7 @@ export const SpecDescriptor = withFallback((props: DescriptorProps) => {
   ) as SpecCapability;
   const Capability = capabilityFor(capability);
 
-  return (
+  return Capability ? (
     <dl className="olm-descriptor">
       <Tooltip content={descriptor.description}>
         <dt className="olm-descriptor__title" data-test-descriptor-label={descriptor.displayName}>
@@ -270,10 +303,11 @@ export const SpecDescriptor = withFallback((props: DescriptorProps) => {
           namespace={namespace}
           model={model}
           obj={obj}
+          onHandleError={onHandleError}
         />
       </dd>
     </dl>
-  );
+  ) : null;
 });
 
 type SpecCapabilityProps = CapabilityProps<SpecCapability>;
