@@ -26,7 +26,6 @@ import {
   k8sCreate,
   K8sResourceKind,
   kindForReference,
-  Status,
   modelFor,
   NodeAffinity as NodeAffinityType,
 } from '@console/internal/module/k8s';
@@ -520,7 +519,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
       const existing = immutableFormData.getIn([...pathToArray(pathBeforeIndex), 0]);
       const item = Immutable.Map(existing || {}).setIn(pathToArray(pathAfterIndex), value);
       const list = Immutable.List([item]);
-      onChange(immutableFormData.setIn(pathToArray(pathBeforeIndex), list));
+      onChange(immutableFormData.setIn(pathToArray(pathBeforeIndex), list).toJS());
     }
     onChange(immutableFormData.setIn(pathToArray(path), value).toJS());
   };
@@ -702,11 +701,14 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
     setFormErrors(errors);
 
     if (_.isEmpty(_.compact(_.values(errors)))) {
-      k8sCreate(model, immutableFormData.setIn(['metadata', 'namespace'], match.params.ns).toJS())
+      k8sCreate(
+        model,
+        model.namespaced
+          ? immutableFormData.setIn(['metadata', 'namespace'], match.params.ns).toJS()
+          : immutableFormData.toJS(),
+      )
         .then(() => history.push(next))
-        .catch((err: { json: Status }) => {
-          setError(err.json.message);
-        });
+        .catch((err: Error) => setError(err.message || 'Unknown error.'));
     }
   };
 
@@ -818,29 +820,25 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
         .split(SpecCapability.k8sResourcePrefix)[1]
         .replace('core~v1~', '');
       const k8sModel = modelFor(groupVersionKind);
-      const selectedKey = currentValue ? `${currentValue}-${k8sModel.kind}` : null;
-
-      return (
-        <div>
-          {!_.isUndefined(model) ? (
-            <ListDropdown
-              id={id}
-              resources={[
-                {
-                  kind: groupVersionKind,
-                  namespace: k8sModel.namespaced ? match?.params?.ns : null,
-                },
-              ]}
-              desc={displayName}
-              placeholder={`Select ${kindForReference(groupVersionKind)}`}
-              onChange={(value) => handleFormDataUpdate(path, value)}
-              selectedKey={selectedKey}
-            />
-          ) : (
-            <span>Cluster does not have resource {groupVersionKind}</span>
-          )}
-        </div>
-      );
+      if (!k8sModel) {
+        // eslint-disable-next-line no-console
+        console.warn('[Legacy CreateOperandForm] Cluster does not have resource', groupVersionKind);
+      }
+      return k8sModel ? (
+        <ListDropdown
+          id={id}
+          resources={[
+            {
+              kind: groupVersionKind,
+              namespace: k8sModel.namespaced ? match?.params?.ns : null,
+            },
+          ]}
+          desc={displayName}
+          placeholder={`Select ${kindForReference(groupVersionKind)}`}
+          onChange={(value) => handleFormDataUpdate(path, value)}
+          selectedKey={currentValue ? `${currentValue}-${k8sModel?.kind}` : null}
+        />
+      ) : null;
     }
     if (capabilities.includes(SpecCapability.checkbox)) {
       return (
