@@ -69,6 +69,8 @@ export const OperatorHubItemDetails: React.SFC<OperatorHubItemDetailsProps> = ({
     support,
     capabilityLevel,
     marketplaceSupportWorkflow,
+    infraFeatures,
+    validSubscription,
   } = item;
   const notAvailable = <span className="properties-side-panel-pf-property-label">N/A</span>;
 
@@ -116,6 +118,12 @@ export const OperatorHubItemDetails: React.SFC<OperatorHubItemDetailsProps> = ({
             process, you can install the Operator on this or other OpenShift clusters. Visit Red Hat
             Marketplace for more details and to track your usage of this application.
           </p>
+          <p>
+            <ExternalLink
+              href="https://marketplace.redhat.com/en-us?utm_source=openshift_console"
+              text="Learn more about the Red Hat Marketplace"
+            />
+          </p>
         </HintBlock>
       );
     }
@@ -123,6 +131,12 @@ export const OperatorHubItemDetails: React.SFC<OperatorHubItemDetailsProps> = ({
     return null;
   };
 
+  const mappedData = (data) =>
+    Array.isArray(data) ? data.map((d) => <div key={d}>{d}</div>) : notAvailable;
+
+  const mappedInfraFeatures = mappedData(infraFeatures);
+  const mappedValidSubscription = mappedData(validSubscription);
+
   return (
     <div className="modal-body modal-body-border">
       <div className="modal-body-content">
@@ -142,6 +156,12 @@ export const OperatorHubItemDetails: React.SFC<OperatorHubItemDetailsProps> = ({
               />
               <PropertyItem label="Provider Type" value={providerType || notAvailable} />
               <PropertyItem label="Provider" value={provider || notAvailable} />
+              {infraFeatures && (
+                <PropertyItem label="Infrastructure Features" value={mappedInfraFeatures} />
+              )}
+              {validSubscription && (
+                <PropertyItem label="Valid Subscriptions" value={mappedValidSubscription} />
+              )}
               <PropertyItem label="Repository" value={repository || notAvailable} />
               <PropertyItem label="Container Image" value={containerImage || notAvailable} />
               <PropertyItem label="Created At" value={createdAt || notAvailable} />
