@@ -5,10 +5,15 @@ export const operatorProviderTypeMap = {
   marketplace: 'Marketplace',
   certified: 'Certified',
   community: 'Community',
-  custom: 'Custom',
 };
 
+const getCustomOperatorProviderType = (packageManifest) =>
+  packageManifest.status.catalogSourceDisplayName || packageManifest.status.catalogSource;
 export const getOperatorProviderType = (packageManifest) => {
   const srcProvider = _.get(packageManifest, 'metadata.labels.opsrc-provider');
-  return _.get(operatorProviderTypeMap, srcProvider, 'Custom');
+  return _.get(
+    operatorProviderTypeMap,
+    srcProvider,
+    getCustomOperatorProviderType(packageManifest),
+  );
 };
