@@ -11,6 +11,7 @@ import {
   Table,
   TableRow,
   TableData,
+  RowFunction,
 } from '@console/internal/components/factory';
 import {
   MsgBox,
@@ -201,12 +202,7 @@ const menuActions = [
   },
 ];
 
-export const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
-  obj,
-  index,
-  key,
-  style,
-}) => {
+export const SubscriptionTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -244,13 +240,6 @@ export const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
     </TableRow>
   );
 };
-SubscriptionTableRow.displayName = 'SubscriptionTableRow';
-export type SubscriptionTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 export const SubscriptionsList = requireOperatorGroup((props: SubscriptionsListProps) => (
   <Table
@@ -307,8 +296,12 @@ export const SubscriptionDetails: React.FC<SubscriptionDetailsProps> = ({
   const catalogSource = catalogSourceForSubscription(catalogSources, obj);
   const installedCSV = installedCSVForSubscription(clusterServiceVersions, obj);
   const installPlan = installPlanForSubscription(installPlans, obj);
-  const installStatusPhase = _.get(installPlan, 'status.phase');
-  const installStatusMessage = _.get(installPlan, 'status.message') || 'Unknown';
+  const installStatusPhase = installPlan?.status?.phase;
+  const installFailedCondition = installPlan?.status?.conditions?.find(
+    ({ type, status }) => type === 'Installed' && status === 'False',
+  );
+  const installFailedMessage =
+    installFailedCondition?.message || installFailedCondition?.reason || 'Install plan failed';
 
   const pkg = packageForSubscription(packageManifests, obj);
   if (new URLSearchParams(window.location.search).has('showDelete')) {
@@ -322,16 +315,18 @@ export const SubscriptionDetails: React.FC<SubscriptionDetailsProps> = ({
       {!catalogSource && (
         <Alert isInline className="co-alert" variant="warning" title="Catalog Source Removed">
           The catalog source for this operator has been removed. The catalog source must be added
-          back in order for this opertor to receive any updates.
+          back in order for this operator to receive any updates.
         </Alert>
       )}
       {installStatusPhase === InstallPlanPhase.InstallPlanPhaseFailed && (
         <Alert
           isInline
-          className="co-alert"
+          className="co-alert co-alert--scrollable"
           variant="danger"
-          title={`${installStatusPhase}: ${installStatusMessage}`}
-        />
+          title={installStatusPhase}
+        >
+          {installFailedMessage}
+        </Alert>
       )}
       <SectionHeading text="Subscription Details" />
       <div className="co-m-pane__body-group">
