@@ -11,8 +11,9 @@ import {
   DragSourceMonitor,
   Identifier,
   DragEvent,
-  DragSpecOperation,
+  DragSpecOperationType,
   DragSource,
+  DragOperationWithType,
 } from './dnd-types';
 import { useDndManager } from './useDndManager';
 
@@ -45,20 +46,25 @@ const getModifiers = (event: MouseEvent | TouchEvent | KeyboardEvent): number =>
   return modifiers;
 };
 
-const getOperation = (operation: DragSpecOperation | undefined): string => {
-  if (typeof operation === 'string') {
-    return operation;
+const getOperation = (
+  operation: DragSpecOperationType<DragOperationWithType> | undefined,
+): DragOperationWithType | undefined => {
+  if (!operation) {
+    return undefined;
+  }
+  if (operation.hasOwnProperty('type')) {
+    return operation as DragOperationWithType;
   }
   return (
-    (operation &&
-      (operation[getModifiers((d3.event && d3.event.sourceEvent) || d3.event)] ||
-        operation[Modifiers.DEFAULT])) ||
-    ''
+    operation[getModifiers((d3.event && d3.event.sourceEvent) || d3.event)] ||
+    operation[Modifiers.DEFAULT]
   );
 };
 
-const hasOperation = (operation: DragSpecOperation | undefined): boolean => {
-  return !!(operation && (typeof operation === 'string' || Object.keys(operation).length > 0));
+const hasOperation = (
+  operation: DragSpecOperationType<DragOperationWithType> | undefined,
+): boolean => {
+  return !!(operation && (operation.hasOwnProperty('type') || Object.keys(operation).length > 0));
 };
 
 const EMPTY_PROPS = Object.freeze({});
@@ -69,7 +75,13 @@ export const useDndDrag = <
   CollectedProps extends {} = {},
   Props extends {} = {}
 >(
-  spec: DragSourceSpec<DragObject, DropResult, CollectedProps, Props>,
+  spec: DragSourceSpec<
+    DragObject,
+    DragSpecOperationType<DragOperationWithType>,
+    DropResult,
+    CollectedProps,
+    Props
+  >,
   props?: Props,
 ): [CollectedProps, ConnectDragSource] => {
   const specRef = React.useRef(spec);
@@ -119,7 +131,7 @@ export const useDndDrag = <
       getDragEvent: (): DragEvent | undefined => {
         return dndManager.getDragEvent();
       },
-      getOperation: (): string => {
+      getOperation: (): DragOperationWithType | undefined => {
         return dndManager.getOperation();
       },
       isCancelled: (): boolean => {
@@ -139,7 +151,7 @@ export const useDndDrag = <
                 drag: [number, number, number, number];
               }
             | undefined;
-          let operation: DragSpecOperation | undefined;
+          let operation: DragSpecOperationType<DragOperationWithType> | undefined;
           d3.select(node).call(
             d3
               .drag()
@@ -316,7 +328,13 @@ export const withDndDrag = <
   CollectedProps extends {} = {},
   Props extends {} = {}
 >(
-  spec: DragSourceSpec<DragObject, DropResult, CollectedProps, Props>,
+  spec: DragSourceSpec<
+    DragObject,
+    DragSpecOperationType<DragOperationWithType>,
+    DropResult,
+    CollectedProps,
+    Props
+  >,
 ) => <P extends WithDndDragProps & CollectedProps & Props>(
   WrappedComponent: React.ComponentType<P>,
 ) => {
