@@ -10,6 +10,7 @@ import {
   ModelKind,
   ADD_CHILD_EVENT,
   REMOVE_CHILD_EVENT,
+  ELEMENT_VISIBILITY_CHANGE_EVENT,
 } from '../types';
 import Stateful from '../utils/Stateful';
 import { Translatable } from '../geom/types';
@@ -125,7 +126,12 @@ export default abstract class BaseElement<E extends ElementModel = ElementModel,
   }
 
   setVisible(visible: boolean): void {
-    this.visible = visible;
+    if (this.visible !== visible) {
+      this.visible = visible;
+      if (this.controller) {
+        this.controller.fireEvent(ELEMENT_VISIBILITY_CHANGE_EVENT, { visible, target: this });
+      }
+    }
   }
 
   isVisible(): boolean {
@@ -167,7 +173,10 @@ export default abstract class BaseElement<E extends ElementModel = ElementModel,
         child.remove();
         child.setParent(this);
         this.children.splice(index, 0, child);
-        this.getController().fireEvent(ADD_CHILD_EVENT, { target: this, child });
+
+        if (this.controller) {
+          this.controller.fireEvent(ADD_CHILD_EVENT, { target: this, child });
+        }
       }
     }
   }
@@ -183,7 +192,10 @@ export default abstract class BaseElement<E extends ElementModel = ElementModel,
         child.remove();
         child.setParent(this);
         this.children.push(child);
-        this.getController().fireEvent(ADD_CHILD_EVENT, { target: this, child });
+
+        if (this.controller) {
+          this.controller.fireEvent(ADD_CHILD_EVENT, { target: this, child });
+        }
       }
     }
   }
@@ -194,7 +206,10 @@ export default abstract class BaseElement<E extends ElementModel = ElementModel,
       if (idx !== -1) {
         this.children.splice(idx, 1);
         child.setParent(undefined);
-        this.getController().fireEvent(REMOVE_CHILD_EVENT, { target: this, child });
+
+        if (this.controller) {
+          this.controller.fireEvent(REMOVE_CHILD_EVENT, { target: this, child });
+        }
       }
     }
   }
@@ -206,6 +221,9 @@ export default abstract class BaseElement<E extends ElementModel = ElementModel,
   }
 
   setModel(model: E): void {
+    if ('type' in model) {
+      this.setType(model.type);
+    }
     if ('visible' in model) {
       this.setVisible(!!model.visible);
     }
@@ -271,4 +289,8 @@ export default abstract class BaseElement<E extends ElementModel = ElementModel,
   translateFromParent(t: Translatable): void {
     // nothing to do
   }
+
+  destroy(): void {
+    // nothing to do
+  }
 }
