@@ -173,7 +173,7 @@ const detectClusterVersion = (dispatch) =>
       if (_.includes([403, 404], _.get(err, 'response.status'))) {
         dispatch(setFlag(FLAGS.CLUSTER_VERSION, false));
       } else {
-        handleError(err, FLAGS.OPENSHIFT, dispatch, detectOpenShift);
+        handleError(err, FLAGS.CLUSTER_VERSION, dispatch, detectClusterVersion);
       }
     },
   );
@@ -261,8 +261,5 @@ export const detectFeatures = () => (dispatch: Dispatch) =>
     detectLoggingURL,
     detectConsoleLinks,
     ...ssarCheckActions,
-    ...plugins.registry
-      .getFeatureFlags()
-      .filter(plugins.isActionFeatureFlag)
-      .map((ff) => ff.properties.detect),
+    ...plugins.registry.getCustomFeatureFlags().map((ff) => ff.properties.detect),
   ].forEach((detect) => detect(dispatch));
