@@ -130,8 +130,8 @@ export const coFetchUtils = {
   parseJson,
 };
 
-export const coFetchJSON = (url, method = 'GET', options = {}, timeout) => {
-  const headers = { Accept: 'application/json' };
+export const coFetchCommon = (url, method = 'GET', options = {}, timeout) => {
+  const headers = {};
   const { kind, name } = store.getState().UI.get('impersonate', {});
   if ((kind === 'User' || kind === 'Group') && name) {
     // Even if we are impersonating a group, we still need to set Impersonate-User to something or k8s will complain
@@ -149,12 +149,24 @@ export const coFetchJSON = (url, method = 'GET', options = {}, timeout) => {
 
     // If the response has no body, return promise that resolves with an empty object
     if (response.headers.get('Content-Length') === '0') {
-      return Promise.resolve({});
+      return Promise.resolve(response.headers.get('Content-Type') === 'text/plain' ? '' : {});
+    }
+    if (response.headers.get('Content-Type') === 'text/plain') {
+      return response.text();
     }
     return response.json();
   });
 };
 
+export const coFetchJSON = (url, method = 'GET', options = {}, timeout) => {
+  const allOptions = _.defaultsDeep({}, options, { headers: { Accept: 'application/json' } });
+  return coFetchCommon(url, method, allOptions, timeout);
+};
+
+export const coFetchText = (url, options = {}, timeout) => {
+  return coFetchCommon(url, 'GET', options, timeout);
+};
+
 const coFetchSendJSON = (url, method, json = null, options = {}, timeout) => {
   const allOptions = {
     headers: {
