@@ -222,7 +222,7 @@ const RoleBindingsTableRow = ({ obj: binding, index, key, style }) => {
         {binding.metadata.namespace ? (
           <ResourceLink kind="Namespace" name={binding.metadata.namespace} />
         ) : (
-          'all'
+          'All Namespaces'
         )}
       </TableData>
       <TableData className={tableColumnClasses[5]}>
@@ -231,7 +231,6 @@ const RoleBindingsTableRow = ({ obj: binding, index, key, style }) => {
     </TableRow>
   );
 };
-RoleBindingsTableRow.displayName = 'RoleBindingsTableRow';
 
 const EmptyMsg = () => (
   <MsgBox
@@ -268,10 +267,10 @@ const roleResources = [
 
 const rowFilters = [
   {
+    filterGroupName: 'Kind',
     type: 'role-binding-kind',
-    selected: ['cluster', 'namespace'],
     reducer: bindingType,
-    items: ({ ClusterRoleBinding: data }) => {
+    itemsGenerator: ({ ClusterRoleBinding: data }) => {
       const items = [
         { id: 'namespace', title: 'Namespace Role Bindings' },
         { id: 'system', title: 'System Role Bindings' },
