@@ -75,7 +75,7 @@ const RolesTableRow = ({ obj: role, index, key, style }) => {
         {role.metadata.namespace ? (
           <ResourceLink kind="Namespace" name={role.metadata.namespace} />
         ) : (
-          'all'
+          'All Namespaces'
         )}
       </TableData>
       <TableData className={roleColumnClasses[2]}>
@@ -84,13 +84,12 @@ const RolesTableRow = ({ obj: role, index, key, style }) => {
     </TableRow>
   );
 };
-RolesTableRow.displayName = 'RolesTableRow';
 
 class Details extends React.Component {
   constructor(props) {
     super(props);
     this.state = {};
-    this.changeFilter = (e) => this.setState({ ruleFilter: e.target.value });
+    this.changeFilter = (val) => this.setState({ ruleFilter: val });
   }
 
   render() {
@@ -202,11 +201,12 @@ const BindingsTableRow = ({ obj: binding, index, key, style }) => {
       </TableData>
       <TableData className={bindingsColumnClasses[1]}>{binding.subject.kind}</TableData>
       <TableData className={bindingsColumnClasses[2]}>{binding.subject.name}</TableData>
-      <TableData className={bindingsColumnClasses[3]}>{binding.namespace || 'all'}</TableData>
+      <TableData className={bindingsColumnClasses[3]}>
+        {binding.namespace || 'All Namespaces'}
+      </TableData>
     </TableRow>
   );
 };
-BindingsTableRow.displayName = 'BindingsTableRow';
 
 const BindingsListComponent = (props) => (
   <BindingsList {...props} Header={BindingsTableHeader} Row={BindingsTableRow} virtualize />
@@ -233,7 +233,7 @@ export const BindingsForRolePage = (props) => {
         }/rolebindings/~new?rolekind=${kind}&rolename=${name}`,
       }}
       ListComponent={BindingsListComponent}
-      staticFilters={[{ 'role-binding-roleRef': name }]}
+      staticFilters={[{ 'role-binding-roleRef-name': name }, { 'role-binding-roleRef-kind': kind }]}
       resources={resources}
       textFilter="role-binding"
       filterLabel="by role or subject"
@@ -307,8 +307,8 @@ export const RolesPage = ({ namespace, mock, showTitle }) => {
       ]}
       rowFilters={[
         {
+          filterGroupName: 'Role',
           type: 'role-kind',
-          selected: ['cluster', 'namespace'],
           reducer: roleType,
           items: [
             { id: 'cluster', title: 'Cluster-wide Roles' },
