@@ -9,7 +9,8 @@ import * as fuzzy from 'fuzzysearch';
 import { Tooltip } from '@patternfly/react-core';
 import { sortable } from '@patternfly/react-table';
 
-import { ALL_NAMESPACES_KEY, FLAGS } from '@console/shared';
+import { ALL_NAMESPACES_KEY, FLAGS, APIError } from '@console/shared';
+import { useAccessReview } from '@console/internal/components/utils';
 import { connectToModel } from '../kinds';
 import { LocalResourceAccessReviewsModel, ResourceAccessReviewsModel } from '../models';
 import {
@@ -21,6 +22,7 @@ import {
   getResourceDescription,
   referenceForModel,
   ResourceAccessReviewRequest,
+  ResourceAccessReviewResponse,
 } from '../module/k8s';
 import { connectToFlags, FlagsObject } from '../reducers/features';
 import { RootState } from '../redux';
@@ -317,11 +319,7 @@ const APIResourcesList = compose(
           />
         </div>
         <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-          <TextFilter
-            value={textFilter}
-            label="by kind"
-            onChange={(e) => setTextFilter(e.target.value)}
-          />
+          <TextFilter value={textFilter} label="by kind" onChange={setTextFilter} />
         </div>
       </div>
       <div className="co-m-pane__body">
@@ -472,8 +470,8 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
   const [showUsers, setShowUsers] = React.useState(true);
   const [showGroups, setShowGroups] = React.useState(true);
   const [showServiceAccounts, setShowServiceAccounts] = React.useState(false);
-  const [accessResponse, setAccessResponse] = React.useState();
-  const [error, setError] = React.useState(null);
+  const [accessResponse, setAccessResponse] = React.useState<ResourceAccessReviewResponse>();
+  const [error, setError] = React.useState<APIError>();
 
   // perform the access review
   React.useEffect(() => {
@@ -535,8 +533,6 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
   const sortedData = _.orderBy(filteredData, ['type', 'name'], ['asc', 'asc']);
 
   // event handlers
-  const onFilterChange: React.ReactEventHandler<HTMLInputElement> = (e) =>
-    setFilter(e.currentTarget.value);
   const toggleShowUsers = (e: React.MouseEvent<HTMLAnchorElement>) => {
     e.preventDefault();
     setShowUsers(!showUsers);
@@ -568,7 +564,7 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
           />
         </div>
         <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-          <TextFilter defaultValue={filter} label="by subject" onChange={onFilterChange} />
+          <TextFilter defaultValue={filter} label="by subject" onChange={(val) => setFilter(val)} />
         </div>
       </div>
       <div className="co-m-pane__body">
@@ -628,6 +624,19 @@ const APIResourcePage_ = ({
   kindsInFlight: boolean;
   flags: FlagsObject;
 }) => {
+  const namespace = kindObj?.namespaced ? match.params.ns : undefined;
+
+  const canCreateResourceAccessReview = useAccessReview({
+    group: namespace
+      ? LocalResourceAccessReviewsModel.apiGroup
+      : ResourceAccessReviewsModel.apiGroup,
+    resource: namespace
+      ? LocalResourceAccessReviewsModel.plural
+      : ResourceAccessReviewsModel.plural,
+    namespace,
+    verb: 'create',
+  });
+
   if (!kindObj) {
     return kindsInFlight ? (
       <LoadingBox />
@@ -670,7 +679,7 @@ const APIResourcePage_ = ({
     });
   }
 
-  if (flags[FLAGS.OPENSHIFT]) {
+  if (flags[FLAGS.OPENSHIFT] && canCreateResourceAccessReview) {
     pages.push({
       href: 'access',
       name: 'Access Review',
@@ -678,8 +687,6 @@ const APIResourcePage_ = ({
     });
   }
 
-  const namespace = kindObj.namespaced ? match.params.ns : null;
-
   return (
     <>
       <ScrollToTopOnMount />
