@@ -26,7 +26,7 @@ import {
   getOCMLink,
 } from '../../../../module/k8s';
 import { flagPending, featureReducerName } from '../../../../reducers/features';
-import { ExternalLink } from '../../../utils';
+import { ExternalLink, useAccessReview } from '../../../utils';
 import { RootState } from '../../../../redux';
 import { clusterUpdateModal } from '../../../modals';
 import { Link } from 'react-router-dom';
@@ -37,6 +37,12 @@ const ClusterVersion: React.FC<ClusterVersionProps> = ({ cv }) => {
   const desiredVersion = getDesiredClusterVersion(cv);
   const lastVersion = getLastCompletedUpdate(cv);
   const status = getClusterUpdateStatus(cv);
+  const clusterVersionIsEditable = useAccessReview({
+    group: ClusterVersionModel.apiGroup,
+    resource: ClusterVersionModel.plural,
+    verb: 'patch',
+    name: 'version',
+  });
 
   switch (status) {
     case ClusterUpdateStatus.Updating:
@@ -55,17 +61,19 @@ const ClusterVersion: React.FC<ClusterVersionProps> = ({ cv }) => {
       return (
         <>
           <span className="co-select-to-copy">{desiredVersion}</span>
-          <div>
-            <Button
-              variant="link"
-              className="btn-link--no-btn-default-values"
-              onClick={() => clusterUpdateModal({ cv })}
-              icon={<ArrowCircleUpIcon />}
-              isInline
-            >
-              Update
-            </Button>
-          </div>
+          {clusterVersionIsEditable && (
+            <div>
+              <Button
+                variant="link"
+                className="btn-link--no-btn-default-values"
+                onClick={() => clusterUpdateModal({ cv })}
+                icon={<ArrowCircleUpIcon />}
+                isInline
+              >
+                Update
+              </Button>
+            </div>
+          )}
         </>
       );
     default:
