@@ -15,9 +15,11 @@ import { DashboardItemProps, withDashboardResources } from '../with-dashboard-re
 import { FirehoseResource, FirehoseResult } from '../../utils';
 import { EventModel } from '../../../models';
 import { EventKind, K8sKind } from '../../../module/k8s';
-import { FlagsObject, featureReducerName } from '../../../reducers/features';
-import * as plugins from '../../../plugins';
-import { isDashboardsOverviewResourceActivity } from '@console/plugin-sdk';
+import {
+  useExtensions,
+  DashboardsOverviewResourceActivity,
+  isDashboardsOverviewResourceActivity,
+} from '@console/plugin-sdk';
 import { uniqueResource } from '../dashboards-page/cluster-dashboard/utils';
 import { RootState } from '../../../redux';
 import { ProjectDashboardContext } from './project-dashboard-context';
@@ -30,8 +32,8 @@ const getEventsResource = (projectName: string): FirehoseResource => ({
   namespace: projectName,
 });
 
-const RecentEvent = withDashboardResources(
-  ({ watchK8sResource, stopWatchK8sResource, resources, projectName }: RecentEventProps) => {
+const RecentEvent = withDashboardResources<RecentEventProps>(
+  ({ watchK8sResource, stopWatchK8sResource, resources, projectName, viewEvents }) => {
     React.useEffect(() => {
       if (projectName) {
         const eventsResource = getEventsResource(projectName);
@@ -41,21 +43,17 @@ const RecentEvent = withDashboardResources(
         };
       }
     }, [watchK8sResource, stopWatchK8sResource, projectName]);
-    return <RecentEventsBody events={resources.events as FirehoseResult<EventKind[]>} />;
+    return (
+      <RecentEventsBody
+        events={resources.events as FirehoseResult<EventKind[]>}
+        moreLink={viewEvents}
+      />
+    );
   },
 );
 
-const getResourceActivities = (flags: FlagsObject, k8sModels: ImmutableMap<string, K8sKind>) =>
-  plugins.registry.getDashboardsOverviewResourceActivities().filter((e) => {
-    const model = k8sModels.get(e.properties.k8sResource.kind);
-    return plugins.registry.isExtensionInUse(e, flags) && model && model.namespaced;
-  });
-
 const mapStateToProps = (state: RootState): OngoingActivityReduxProps => ({
   models: state.k8s.getIn(['RESOURCES', 'models']) as ImmutableMap<string, K8sKind>,
-  flags: plugins.registry
-    .getGatingFlagNames([isDashboardsOverviewResourceActivity])
-    .reduce((allFlags, f) => ({ ...allFlags, [f]: state[featureReducerName].get(f) }), {}),
 });
 
 const OngoingActivity = connect(mapStateToProps)(
@@ -64,13 +62,24 @@ const OngoingActivity = connect(mapStateToProps)(
       watchK8sResource,
       stopWatchK8sResource,
       resources,
-      flags,
       projectName,
       models,
     }: DashboardItemProps & OngoingActivityProps) => {
+      const resourceActivityExtensions = useExtensions<DashboardsOverviewResourceActivity>(
+        isDashboardsOverviewResourceActivity,
+      );
+
+      const resourceActivities = React.useMemo(
+        () =>
+          resourceActivityExtensions.filter((e) => {
+            const model = models.get(e.properties.k8sResource.kind);
+            return model && model.namespaced;
+          }),
+        [resourceActivityExtensions, models],
+      );
+
       React.useEffect(() => {
         if (projectName) {
-          const resourceActivities = getResourceActivities(flags, models);
           resourceActivities.forEach((a, index) => {
             watchK8sResource(
               uniqueResource({ ...a.properties.k8sResource, namespace: projectName }, index),
@@ -82,31 +91,37 @@ const OngoingActivity = connect(mapStateToProps)(
             });
           };
         }
-        // TODO: to be removed: use JSON.stringify(flags) to avoid deep comparison of flags object
-        // eslint-disable-next-line react-hooks/exhaustive-deps
-      }, [watchK8sResource, stopWatchK8sResource, models, JSON.stringify(flags)]);
+      }, [watchK8sResource, stopWatchK8sResource, projectName, resourceActivities]);
 
-      const resourceActivities = getResourceActivities(flags, models);
-      const allResourceActivities = _.flatten(
-        resourceActivities.map((a, index) => {
-          const k8sResources = _.get(
-            resources,
-            [uniqueResource(a.properties.k8sResource, index).prop, 'data'],
-            [],
-          ) as FirehoseResult['data'];
-          return k8sResources
-            .filter((r) => (a.properties.isActivity ? a.properties.isActivity(r) : true))
-            .map((r) => ({
-              resource: r,
-              timestamp: a.properties.getTimestamp ? a.properties.getTimestamp(r) : null,
-              loader: a.properties.loader,
-            }));
-        }),
+      const allResourceActivities = React.useMemo(
+        () =>
+          _.flatten(
+            resourceActivities.map((a, index) => {
+              const k8sResources = _.get(
+                resources,
+                [uniqueResource(a.properties.k8sResource, index).prop, 'data'],
+                [],
+              ) as FirehoseResult['data'];
+              return k8sResources
+                .filter((r) => (a.properties.isActivity ? a.properties.isActivity(r) : true))
+                .map((r) => ({
+                  resource: r,
+                  timestamp: a.properties.getTimestamp ? a.properties.getTimestamp(r) : null,
+                  loader: a.properties.loader,
+                }));
+            }),
+          ),
+        [resourceActivities, resources],
       );
 
-      const resourcesLoaded = resourceActivities.every((a, index) =>
-        _.get(resources, [uniqueResource(a.properties.k8sResource, index).prop, 'loaded']),
+      const resourcesLoaded = React.useMemo(
+        () =>
+          resourceActivities.every((a, index) =>
+            _.get(resources, [uniqueResource(a.properties.k8sResource, index).prop, 'loaded']),
+          ),
+        [resourceActivities, resources],
       );
+
       return (
         <OngoingActivityBody
           loaded={projectName && resourcesLoaded && models.size !== 0}
@@ -120,16 +135,17 @@ const OngoingActivity = connect(mapStateToProps)(
 export const ActivityCard: React.FC = () => {
   const { obj } = React.useContext(ProjectDashboardContext);
   const projectName = getName(obj);
+  const viewEvents = `/k8s/ns/${projectName}/events`;
   return (
-    <DashboardCard gradient>
+    <DashboardCard gradient data-test-id="activity-card">
       <DashboardCardHeader>
         <DashboardCardTitle>Activity</DashboardCardTitle>
-        <DashboardCardLink to={`/k8s/ns/${projectName}/events`}>View events</DashboardCardLink>
+        <DashboardCardLink to={viewEvents}>View events</DashboardCardLink>
       </DashboardCardHeader>
       <DashboardCardBody>
         <ActivityBody className="co-project-dashboard__activity-body">
           <OngoingActivity projectName={projectName} />
-          <RecentEvent projectName={projectName} />
+          <RecentEvent projectName={projectName} viewEvents={viewEvents} />
         </ActivityBody>
       </DashboardCardBody>
     </DashboardCard>
@@ -138,10 +154,10 @@ export const ActivityCard: React.FC = () => {
 
 type RecentEventProps = DashboardItemProps & {
   projectName: string;
+  viewEvents: string;
 };
 
 type OngoingActivityReduxProps = {
-  flags: FlagsObject;
   models: ImmutableMap<string, K8sKind>;
 };
 
