@@ -4,7 +4,7 @@ import * as classNames from 'classnames';
 import { sortable } from '@patternfly/react-table';
 import { K8sResourceKindReference, K8sResourceKind } from '../module/k8s';
 import { LimitRangeModel } from '../models';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import {
   Kebab,
   navFactory,
@@ -27,12 +27,7 @@ const tableColumnClasses = [
   Kebab.columnClass,
 ];
 
-export const LimitRangeTableRow: React.FC<LimitRangeTableRowProps> = ({
-  obj,
-  index,
-  key,
-  style,
-}) => {
+export const LimitRangeTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -58,13 +53,6 @@ export const LimitRangeTableRow: React.FC<LimitRangeTableRowProps> = ({
     </TableRow>
   );
 };
-LimitRangeTableRow.displayName = 'LimitRangeTableRow';
-type LimitRangeTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 export const LimitRangeTableHeader = () => {
   return [
