@@ -20,7 +20,8 @@ import { ByteDataTypes } from '@console/shared/src/graph-helper/data-utils';
 
 import { NamespaceModel, ProjectModel, SecretModel } from '../models';
 import { coFetchJSON } from '../co-fetch';
-import { k8sGet } from '../module/k8s';
+import { k8sGet, referenceForModel } from '../module/k8s';
+import * as k8sActions from '../actions/k8s';
 import * as UIActions from '../actions/ui';
 import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
 import {
@@ -37,6 +38,7 @@ import {
   ResourceLink,
   ResourceSummary,
   SectionHeading,
+  Timestamp,
   formatBytesAsMiB,
   formatCores,
   humanizeBinaryBytes,
@@ -44,7 +46,6 @@ import {
   navFactory,
   useAccessReview,
 } from './utils';
-import { fromNow } from './utils/datetime';
 import {
   createNamespaceModal,
   createProjectModal,
@@ -61,6 +62,7 @@ import {
   getNamespaceDashboardConsoleLinks,
   ProjectDashboard,
 } from './dashboard/project-dashboard/project-dashboard';
+import { removeQueryArgument } from './utils/router';
 
 const getModel = (useProjects) => (useProjects ? ProjectModel : NamespaceModel);
 const getDisplayName = (obj) =>
@@ -173,7 +175,7 @@ const NamespacesTableRow = ({ obj: ns, index, key, style }) => {
         <LabelList kind="Namespace" labels={ns.metadata.labels} />
       </TableData>
       <TableData className={namespacesColumnClasses[3]}>
-        {fromNow(ns.metadata.creationTimestamp)}
+        <Timestamp timestamp={ns.metadata.creationTimestamp} />
       </TableData>
       <TableData className={namespacesColumnClasses[4]}>
         <ResourceKebab actions={nsMenuActions} kind="Namespace" resource={ns} />
@@ -181,7 +183,6 @@ const NamespacesTableRow = ({ obj: ns, index, key, style }) => {
     </TableRow>
   );
 };
-NamespacesTableRow.displayName = 'NamespacesTableRow';
 
 export const NamespacesList = (props) => (
   <Table
@@ -202,7 +203,7 @@ export const NamespacesPage = (props) => (
   />
 );
 
-const projectMenuActions = [Kebab.factory.Edit, deleteModal];
+export const projectMenuActions = [Kebab.factory.Edit, deleteModal];
 
 const projectColumnClasses = [
   '', // name
@@ -267,23 +268,29 @@ const projectTableHeader = ({ showMetrics, showActions }) => {
   ];
 };
 
-const ProjectLink = connect(null, { setActiveNamespace: UIActions.setActiveNamespace })(
-  ({ project, setActiveNamespace }) => (
-    <span className="co-resource-item co-resource-item--truncate">
-      <ResourceIcon kind="Project" />
-      <Button
-        isInline
-        title={project.metadata.name}
-        type="button"
-        className="co-resource-item__resource-name"
-        onClick={() => setActiveNamespace(project.metadata.name)}
-        variant="link"
-      >
-        {project.metadata.name}
-      </Button>
-    </span>
-  ),
-);
+const ProjectLink = connect(null, {
+  setActiveNamespace: UIActions.setActiveNamespace,
+  filterList: k8sActions.filterList,
+})(({ project, setActiveNamespace, filterList }) => (
+  <span className="co-resource-item co-resource-item--truncate">
+    <ResourceIcon kind="Project" />
+    <Button
+      isInline
+      title={project.metadata.name}
+      type="button"
+      className="co-resource-item__resource-name"
+      onClick={() => {
+        setActiveNamespace(project.metadata.name);
+        removeQueryArgument('project-name');
+        // clear project-name filter when active namespace is changed
+        filterList(referenceForModel(ProjectModel), 'project-name', '');
+      }}
+      variant="link"
+    >
+      {project.metadata.name}
+    </Button>
+  </span>
+));
 const projectHeaderWithoutActions = () =>
   projectTableHeader({ showMetrics: false, showActions: false });
 
@@ -292,13 +299,13 @@ const projectRowStateToProps = ({ UI }) => ({
 });
 
 const ProjectTableRow = connect(projectRowStateToProps)(
-  ({ obj: project, index, key, style, customData = {}, metrics }) => {
+  ({ obj: project, index, rowKey, style, customData = {}, metrics }) => {
     const requester = getRequester(project);
     const { ProjectLinkComponent, actionsEnabled = true, showMetrics } = customData;
     const bytes = _.get(metrics, ['memory', project.metadata.name]);
     const cores = _.get(metrics, ['cpu', project.metadata.name]);
     return (
-      <TableRow id={project.metadata.uid} index={index} trKey={key} style={style}>
+      <TableRow id={project.metadata.uid} index={index} trKey={rowKey} style={style}>
         <TableData className={projectColumnClasses[0]}>
           {customData && ProjectLinkComponent ? (
             <ProjectLinkComponent project={project} />
@@ -334,7 +341,7 @@ const ProjectTableRow = connect(projectRowStateToProps)(
           </>
         )}
         <TableData className={projectColumnClasses[6]}>
-          {fromNow(project.metadata.creationTimestamp)}
+          <Timestamp timestamp={project.metadata.creationTimestamp} />
         </TableData>
         {actionsEnabled && (
           <TableData className={projectColumnClasses[7]}>
@@ -347,7 +354,16 @@ const ProjectTableRow = connect(projectRowStateToProps)(
 );
 ProjectTableRow.displayName = 'ProjectTableRow';
 
-const Row = (rowProps) => <ProjectTableRow {...rowProps} />;
+const Row = (rowArgs) => (
+  <ProjectTableRow
+    obj={rowArgs.obj}
+    index={rowArgs.index}
+    rowKey={rowArgs.key}
+    style={rowArgs.style}
+    customData={rowArgs.customData}
+  />
+);
+
 export const ProjectsTable = (props) => (
   <Table
     {...props}
@@ -541,12 +557,12 @@ export const NamespaceSummary = ({ ns }) => {
   );
 };
 
-const NamespaceDetails_ = ({ obj: ns, consoleLinks }) => {
+const NamespaceDetails_ = ({ obj: ns, consoleLinks, customData }) => {
   const links = getNamespaceDashboardConsoleLinks(ns, consoleLinks);
   return (
     <div>
       <div className="co-m-pane__body">
-        <SectionHeading text={`${ns.kind} Details`} />
+        {!customData?.hideHeading && <SectionHeading text={`${ns.kind} Details`} />}
         <NamespaceSummary ns={ns} />
       </div>
       {ns.kind === 'Namespace' && <ResourceUsage ns={ns} />}
@@ -572,7 +588,7 @@ const DetailsStateToProps = ({ UI }) => ({
   consoleLinks: UI.get('consoleLinks'),
 });
 
-const NamespaceDetails = connect(DetailsStateToProps)(NamespaceDetails_);
+export const NamespaceDetails = connect(DetailsStateToProps)(NamespaceDetails_);
 
 const RolesPage = ({ obj: { metadata } }) => (
   <RoleBindingsPage
@@ -654,11 +670,15 @@ class NamespaceBarDropdowns_ extends React.Component {
       if (newNamespace === CREATE_NEW_RESOURCE) {
         createProjectModal({
           blocking: true,
-          onSubmit: (newProject) => setActiveNamespace(newProject.metadata.name),
+          onSubmit: (newProject) => {
+            setActiveNamespace(newProject.metadata.name);
+            removeQueryArgument('project-name');
+          },
         });
       } else {
         onNamespaceChange && onNamespaceChange(newNamespace);
         setActiveNamespace(newNamespace);
+        removeQueryArgument('project-name');
       }
     };
 
