@@ -19,7 +19,7 @@ import {
 } from '../module/k8s/pods';
 import { getContainerState, getContainerStatus } from '../module/k8s/container';
 import { ResourceEventStream } from './events';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunctionArgs } from './factory';
 import {
   AsyncComponent,
   DetailsItem,
@@ -42,7 +42,6 @@ import {
   pluralize,
   units,
 } from './utils';
-import { fromNow } from './utils/datetime';
 import { PodLogs } from './pod-logs';
 import {
   Area,
@@ -115,7 +114,14 @@ const podRowStateToProps = ({ UI }) => ({
 });
 
 const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(podRowStateToProps)(
-  ({ obj: pod, index, key, style, metrics }: PodTableRowProps & PodTableRowPropsFromState) => {
+  ({
+    obj: pod,
+    index,
+    rowKey,
+    style,
+    metrics,
+    showNodes,
+  }: PodTableRowProps & PodTableRowPropsFromState) => {
     const { name, namespace, creationTimestamp } = pod.metadata;
     const { readyCount, totalContainers } = podReadiness(pod);
     const phase = podPhase(pod);
@@ -123,7 +129,7 @@ const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(p
     const bytes: number = _.get(metrics, ['memory', namespace, name]);
     const cores: number = _.get(metrics, ['cpu', namespace, name]);
     return (
-      <TableRow id={pod.metadata.uid} index={index} trKey={key} style={style}>
+      <TableRow id={pod.metadata.uid} index={index} trKey={rowKey} style={style}>
         <TableData className={tableColumnClasses[0]}>
           <ResourceLink kind={kind} name={name} namespace={namespace} />
         </TableData>
@@ -138,7 +144,11 @@ const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(p
         </TableData>
         <TableData className={tableColumnClasses[4]}>{restarts}</TableData>
         <TableData className={tableColumnClasses[5]}>
-          <OwnerReferences resource={pod} />
+          {showNodes ? (
+            <ResourceLink kind="Node" name={pod.spec.nodeName} namespace={namespace} />
+          ) : (
+            <OwnerReferences resource={pod} />
+          )}
         </TableData>
         <TableData className={tableColumnClasses[6]}>
           {bytes ? `${formatBytesAsMiB(bytes)} MiB` : '-'}
@@ -146,7 +156,9 @@ const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(p
         <TableData className={tableColumnClasses[7]}>
           {cores ? `${formatCores(cores)} cores` : '-'}
         </TableData>
-        <TableData className={tableColumnClasses[8]}>{fromNow(creationTimestamp)}</TableData>
+        <TableData className={tableColumnClasses[8]}>
+          <Timestamp timestamp={creationTimestamp} />
+        </TableData>
         <TableData className={tableColumnClasses[9]}>
           <ResourceKebab
             actions={menuActions}
@@ -161,71 +173,72 @@ const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(p
 );
 PodTableRow.displayName = 'PodTableRow';
 
-const PodTableHeader = () => {
-  return [
-    {
-      title: 'Name',
-      sortField: 'metadata.name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[0] },
-    },
-    {
-      title: 'Namespace',
-      sortField: 'metadata.namespace',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[1] },
-    },
-    {
-      title: 'Status',
-      sortFunc: 'podPhase',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[2] },
-    },
-    {
-      title: 'Ready',
-      sortFunc: 'podReadiness',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[3] },
-    },
-    {
-      title: 'Restarts',
-      sortFunc: 'podRestarts',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[4] },
-    },
-    {
-      title: 'Owner',
-      sortField: 'metadata.ownerReferences[0].name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[5] },
-    },
-    {
-      title: 'Memory',
-      sortFunc: 'podMemory',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[6] },
-    },
-    {
-      title: 'CPU',
-      sortFunc: 'podCPU',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[7] },
-    },
-    {
-      title: 'Created',
-      sortField: 'metadata.creationTimestamp',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[8] },
-    },
-    {
-      title: '',
-      props: { className: tableColumnClasses[9] },
-    },
-  ];
+const getHeader = (showNodes) => {
+  return () => {
+    return [
+      {
+        title: 'Name',
+        sortField: 'metadata.name',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[0] },
+      },
+      {
+        title: 'Namespace',
+        sortField: 'metadata.namespace',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[1] },
+      },
+      {
+        title: 'Status',
+        sortFunc: 'podPhase',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[2] },
+      },
+      {
+        title: 'Ready',
+        sortFunc: 'podReadiness',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[3] },
+      },
+      {
+        title: 'Restarts',
+        sortFunc: 'podRestarts',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[4] },
+      },
+      {
+        title: showNodes ? 'Node' : 'Owner',
+        sortField: showNodes ? 'spec.nodeName' : 'metadata.ownerReferences[0].name',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[5] },
+      },
+      {
+        title: 'Memory',
+        sortFunc: 'podMemory',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[6] },
+      },
+      {
+        title: 'CPU',
+        sortFunc: 'podCPU',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[7] },
+      },
+      {
+        title: 'Created',
+        sortField: 'metadata.creationTimestamp',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[8] },
+      },
+      {
+        title: '',
+        props: { className: tableColumnClasses[9] },
+      },
+    ];
+  };
 };
-PodTableHeader.displayName = 'PodTableHeader';
 
-const ContainerLink: React.FC<ContainerLinkProps> = ({ pod, name }) => (
+export const ContainerLink: React.FC<ContainerLinkProps> = ({ pod, name }) => (
   <span className="co-resource-item co-resource-item--inline">
     <ResourceIcon kind="Container" />
     <Link to={`/k8s/ns/${pod.metadata.namespace}/pods/${pod.metadata.name}/containers/${name}`}>
@@ -233,6 +246,7 @@ const ContainerLink: React.FC<ContainerLinkProps> = ({ pod, name }) => (
     </Link>
   </span>
 );
+ContainerLink.displayName = 'ContainerLink';
 
 export const ContainerRow: React.FC<ContainerRowProps> = ({ pod, container }) => {
   const cstatus = getContainerStatus(pod, container.name);
@@ -459,12 +473,16 @@ const PodEnvironmentComponent = (props) => (
   <EnvironmentPage obj={props.obj} rawEnvData={props.obj.spec} envPath={envPath} readOnly={true} />
 );
 
-const PodExecLoader: React.FC<PodExecLoaderProps> = ({ obj }) => (
+export const PodExecLoader: React.FC<PodExecLoaderProps> = ({ obj, message }) => (
   <div className="co-m-pane__body">
     <div className="row">
       <div className="col-xs-12">
         <div className="panel-body">
-          <AsyncComponent loader={() => import('./pod-exec').then((c) => c.PodExec)} obj={obj} />
+          <AsyncComponent
+            loader={() => import('./pod-exec').then((c) => c.PodExec)}
+            obj={obj}
+            message={message}
+          />
         </div>
       </div>
     </div>
@@ -492,16 +510,36 @@ export const PodsDetailsPage: React.FC<PodDetailsPageProps> = (props) => (
 );
 PodsDetailsPage.displayName = 'PodsDetailsPage';
 
-const Row = (rowProps: PodTableRowProps) => <PodTableRow {...rowProps} />;
-export const PodList: React.FC = (props) => (
-  <Table {...props} aria-label="Pods" Header={PodTableHeader} Row={Row} virtualize />
-);
+const getRow = (showNodes) => {
+  return (rowArgs: RowFunctionArgs<PodKind>) => (
+    <PodTableRow
+      obj={rowArgs.obj}
+      index={rowArgs.index}
+      rowKey={rowArgs.key}
+      style={rowArgs.style}
+      showNodes={showNodes}
+    />
+  );
+};
+
+export const PodList: React.FC<PodListProps> = (props) => {
+  const showNodes = props?.customData?.showNodes;
+  return (
+    <Table
+      {...props}
+      aria-label="Pods"
+      Header={getHeader(showNodes)}
+      Row={getRow(showNodes)}
+      virtualize
+    />
+  );
+};
 PodList.displayName = 'PodList';
 
 const filters = [
   {
+    filterGroupName: 'Status',
     type: 'pod-status',
-    selected: ['Running', 'Pending', 'Terminating', 'CrashLoopBackOff'],
     reducer: podPhaseFilterReducer,
     items: [
       { id: 'Running', title: 'Running' },
@@ -525,7 +563,7 @@ export const PodsPage = connect<{}, PodPagePropsFromDispatch, PodPageProps>(
   null,
   dispatchToProps,
 )((props: PodPageProps & PodPagePropsFromDispatch) => {
-  const { canCreate = true, namespace, setPodMetrics, ...listProps } = props;
+  const { canCreate = true, namespace, setPodMetrics, customData, ...listProps } = props;
   /* eslint-disable react-hooks/exhaustive-deps */
   React.useEffect(() => {
     if (showMetrics) {
@@ -554,6 +592,7 @@ export const PodsPage = connect<{}, PodPagePropsFromDispatch, PodPageProps>(
       ListComponent={PodList}
       rowFilters={filters}
       namespace={namespace}
+      customData={customData}
     />
   );
 });
@@ -588,6 +627,7 @@ type PodDetailsListProps = {
 
 type PodExecLoaderProps = {
   obj: PodKind;
+  message?: React.ReactElement;
 };
 
 type PodDetailsProps = {
@@ -597,20 +637,26 @@ type PodDetailsProps = {
 type PodTableRowProps = {
   obj: PodKind;
   index: number;
-  key?: string;
+  rowKey: string;
   style: object;
+  showNodes?: boolean;
 };
 
 type PodTableRowPropsFromState = {
   metrics: UIActions.PodMetrics;
 };
 
+type PodListProps = {
+  customData?: any;
+};
+
 type PodPageProps = {
   canCreate?: boolean;
   fieldSelector?: any;
   namespace?: string;
   selector?: any;
   showTitle?: boolean;
+  customData?: any;
 };
 
 type PodPagePropsFromDispatch = {
