@@ -21,12 +21,13 @@ import {
   ResourceKebab,
   asAccessReview,
   OwnerReferences,
+  Timestamp,
+  PodsComponent,
 } from './utils';
 
 import { VolumesTable } from './volumes-table';
 import { confirmModal } from './modals';
 import { k8sPatch } from '../module/k8s';
-import { fromNow } from './utils/datetime';
 
 const Details = ({ obj: replicationController }) => {
   const revision = _.get(replicationController, [
@@ -131,6 +132,10 @@ const CancelAction = (kind, obj) => ({
   accessReview: asAccessReview(kind, obj, 'patch'),
 });
 
+const ReplicationControllerPods = (props) => (
+  <PodsComponent {...props} customData={{ showNodes: true }} />
+);
+
 const menuActions = [CancelAction, ...replicaSetMenuActions];
 
 export const ReplicationControllersDetailsPage = (props) => (
@@ -143,7 +148,7 @@ export const ReplicationControllersDetailsPage = (props) => (
     pages={[
       details(Details),
       editYaml(),
-      pods(),
+      pods(ReplicationControllerPods),
       envEditor(environmentComponent),
       events(ResourceEventStream),
     ]}
@@ -197,7 +202,7 @@ const ReplicationControllerTableRow = ({ obj, index, key, style }) => {
         <OwnerReferences resource={obj} />
       </TableData>
       <TableData className={tableColumnClasses[5]}>
-        {fromNow(obj.metadata.creationTimestamp)}
+        <Timestamp timestamp={obj.metadata.creationTimestamp} />
       </TableData>
       <TableData className={tableColumnClasses[6]}>
         <ResourceKebab actions={menuActions} kind={kind} resource={obj} />
@@ -205,7 +210,6 @@ const ReplicationControllerTableRow = ({ obj, index, key, style }) => {
     </TableRow>
   );
 };
-ReplicationControllerTableRow.displayName = 'ReplicationControllerTableRow';
 
 const ReplicationControllerTableHeader = () => {
   return [
