@@ -150,7 +150,6 @@ export const ResourceQuotaTableRow = ({ obj: rq, index, key, style }) => {
     </TableRow>
   );
 };
-ResourceQuotaTableRow.displayName = 'ResourceQuotaTableRow';
 
 export const UsageIcon = ({ percent }) => {
   let usageIcon = <UnknownIcon />;
@@ -400,8 +399,8 @@ export const ResourceQuotasPage = connectToFlags(FLAGS.OPENSHIFT)(({ namespace,
     });
     rowFilters = [
       {
+        filterGroupName: 'Role',
         type: 'role-kind',
-        selected: ['cluster', 'namespace'],
         reducer: quotaType,
         items: [
           { id: 'cluster', title: 'Cluster-wide Resource Quotas' },
