@@ -192,7 +192,9 @@ export class CreateRoute extends React.Component<{}, CreateRouteState> {
 
     // If the port is unnamed, there is only one port. Use the port number.
     const targetPort =
-      selectedPort === UNNAMED_PORT_KEY ? _.get(service, 'spec.ports[0].port') : selectedPort;
+      selectedPort === UNNAMED_PORT_KEY
+        ? _.get(service, 'spec.ports[0].targetPort') || _.get(service, 'spec.ports[0].port')
+        : selectedPort;
 
     const alternateBackends = _.filter(alternateServices, 'name').map(
       (serviceData: AlternateServiceEntryType) => {
