@@ -3,7 +3,7 @@ import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { Link } from 'react-router-dom';
 import { ActionGroup, Button } from '@patternfly/react-core';
-import { filterScOnProvisioner, isCephProvisioner } from '@console/shared/src/utils';
+import { isCephProvisioner, isObjectSC } from '@console/shared/src/utils';
 import { k8sCreate, K8sResourceKind, referenceFor } from '../../module/k8s';
 import { AsyncComponent, ButtonBar, RequestSizeInput, history, resourceObjPath } from '../utils';
 import { StorageClassDropdown } from '../utils/storage-class-dropdown';
@@ -190,10 +190,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
     setAccessMode(event.currentTarget.value);
   };
 
-  const onlyPvcSCs = React.useCallback(
-    (sc: StorageClass) => !filterScOnProvisioner(sc, 'noobaa.io/obc'),
-    [],
-  );
+  const onlyPvcSCs = React.useCallback((sc: StorageClass) => !isObjectSC(sc), []);
 
   return (
     <div>
@@ -266,6 +263,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
         defaultRequestSizeValue={requestSizeValue}
         dropdownUnits={dropdownUnits}
         describedBy="request-size-help"
+        inputID="request-size-input"
       />
       <p className="help-block" id="request-size-help">
         Desired storage capacity.
