@@ -5,7 +5,10 @@ import * as PropTypes from 'prop-types';
 import { connect } from 'react-redux';
 import { CaretDownIcon, MinusCircleIcon, PlusCircleIcon, StarIcon } from '@patternfly/react-icons';
 import { impersonateStateToProps } from '../../reducers/ui';
-import { checkAccess, history, KebabItems, ResourceName } from './index';
+import { checkAccess } from './rbac';
+import { history } from './router';
+import { KebabItems } from './kebab';
+import { ResourceName } from './resource-icon';
 import { useSafetyFirst } from '../safety-first';
 
 export class DropdownMixin extends React.PureComponent {
@@ -407,6 +410,7 @@ export class Dropdown extends DropdownMixin {
       favoriteKey,
     } = this.state;
     const {
+      ariaLabel,
       autocompleteFilter,
       autocompletePlaceholder,
       className,
@@ -560,6 +564,7 @@ export class Dropdown extends DropdownMixin {
           )}
         >
           <button
+            aria-label={ariaLabel}
             aria-haspopup="true"
             aria-expanded={this.state.active}
             className={classNames('pf-c-dropdown__toggle', buttonClassName)}
