@@ -4,7 +4,8 @@ import * as PropTypes from 'prop-types';
 import { connect } from 'react-redux';
 import { Map as ImmutableMap } from 'immutable';
 
-import { inject, makeReduxID, makeQuery } from './index';
+import { inject } from './inject';
+import { makeReduxID, makeQuery } from './k8s-watcher';
 import * as k8sActions from '../../actions/k8s';
 
 const shallowMapEquals = (a, b) => {
@@ -240,13 +241,16 @@ export const Firehose = connect(
           return children;
         }
 
-        const reduxes = this.state.firehoses.map(({ id, prop, isList, filters, optional }) => ({
-          reduxID: id,
-          prop,
-          isList,
-          filters,
-          optional,
-        }));
+        const reduxes = this.state.firehoses.map(
+          ({ id, prop, isList, filters, optional, kind }) => ({
+            reduxID: id,
+            prop,
+            isList,
+            filters,
+            optional,
+            kind,
+          }),
+        );
         return <ConnectToState reduxes={reduxes}>{children}</ConnectToState>;
       }
       return null;
