@@ -1,102 +1,5 @@
 import { K8sKind } from '../module/k8s';
 
-export const CatalogSourceConfigModel: K8sKind = {
-  kind: 'CatalogSourceConfig',
-  label: 'CatalogSourceConfig',
-  labelPlural: 'CatalogSourceConfigs',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1',
-  abbr: 'CSC',
-  namespaced: true,
-  crd: true,
-  plural: 'catalogsourceconfigs',
-};
-
-export const OperatorSourceModel: K8sKind = {
-  kind: 'OperatorSource',
-  label: 'OperatorSource',
-  labelPlural: 'OperatorSource',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1',
-  abbr: 'OSRC',
-  namespaced: true,
-  crd: true,
-  plural: 'operatorsources',
-};
-
-export const CatalogSourceModel: K8sKind = {
-  kind: 'CatalogSource',
-  label: 'CatalogSource',
-  labelPlural: 'CatalogSources',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1alpha1',
-  abbr: 'CS',
-  namespaced: true,
-  crd: true,
-  plural: 'catalogsources',
-};
-
-export const PackageManifestModel: K8sKind = {
-  kind: 'PackageManifest',
-  label: 'PackageManifest',
-  labelPlural: 'PackageManifests',
-  apiGroup: 'packages.operators.coreos.com',
-  apiVersion: 'v1',
-  abbr: 'PM',
-  namespaced: true,
-  crd: true,
-  plural: 'packagemanifests',
-};
-
-export const ClusterServiceVersionModel: K8sKind = {
-  kind: 'ClusterServiceVersion',
-  label: 'ClusterServiceVersion',
-  labelPlural: 'ClusterServiceVersions',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1alpha1',
-  abbr: 'CSV',
-  namespaced: true,
-  crd: true,
-  plural: 'clusterserviceversions',
-  propagationPolicy : 'Foreground',
-};
-
-export const InstallPlanModel: K8sKind = {
-  kind: 'InstallPlan',
-  label: 'InstallPlan',
-  labelPlural: 'InstallPlans',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1alpha1',
-  abbr: 'IP',
-  namespaced: true,
-  crd: true,
-  plural: 'installplans',
-};
-
-export const SubscriptionModel: K8sKind = {
-  kind: 'Subscription',
-  label: 'Subscription',
-  labelPlural: 'Subscriptions',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1alpha1',
-  abbr: 'SUB',
-  namespaced: true,
-  crd: true,
-  plural: 'subscriptions',
-};
-
-export const OperatorGroupModel: K8sKind = {
-  kind: 'OperatorGroup',
-  label: 'OperatorGroup',
-  labelPlural: 'OperatorGroups',
-  apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1',
-  abbr: 'OG',
-  namespaced: true,
-  crd: true,
-  plural: 'operatorgroups',
-};
-
 export const PrometheusModel: K8sKind = {
   kind: 'Prometheus',
   label: 'Prometheus',
@@ -107,7 +10,7 @@ export const PrometheusModel: K8sKind = {
   namespaced: true,
   crd: true,
   plural: 'prometheuses',
-  propagationPolicy : 'Foreground',
+  propagationPolicy: 'Foreground',
 };
 
 export const ServiceMonitorModel: K8sKind = {
@@ -120,7 +23,7 @@ export const ServiceMonitorModel: K8sKind = {
   namespaced: true,
   crd: true,
   plural: 'servicemonitors',
-  propagationPolicy : 'Foreground',
+  propagationPolicy: 'Foreground',
 };
 
 export const AlertmanagerModel: K8sKind = {
@@ -133,7 +36,7 @@ export const AlertmanagerModel: K8sKind = {
   namespaced: true,
   crd: true,
   plural: 'alertmanagers',
-  propagationPolicy : 'Foreground',
+  propagationPolicy: 'Foreground',
 };
 
 export const ChargebackReportModel: K8sKind = {
@@ -148,6 +51,18 @@ export const ChargebackReportModel: K8sKind = {
   namespaced: true,
 };
 
+export const ReportQueryModel: K8sKind = {
+  kind: 'ReportQuery',
+  label: 'ReportQuery',
+  labelPlural: 'Report Queries',
+  apiGroup: 'metering.openshift.io',
+  apiVersion: 'v1',
+  crd: true,
+  plural: 'reportqueries',
+  abbr: 'RQ',
+  namespaced: true,
+};
+
 export const ServiceModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Service',
@@ -435,7 +350,7 @@ export const ProjectRequestModel: K8sKind = {
 export const IngressModel: K8sKind = {
   label: 'Ingress',
   labelPlural: 'Ingresses',
-  apiGroup: 'extensions',
+  apiGroup: 'networking.k8s.io',
   apiVersion: 'v1beta1',
   plural: 'ingresses',
   abbr: 'I',
@@ -663,7 +578,7 @@ export const CronJobModel: K8sKind = {
   kind: 'CronJob',
   id: 'cronjob',
   labelPlural: 'Cron Jobs',
-  propagationPolicy : 'Foreground',
+  propagationPolicy: 'Foreground',
 };
 
 export const StorageClassModel: K8sKind = {
@@ -767,6 +682,32 @@ export const APIServiceModel: K8sKind = {
   crd: true,
 };
 
+export const UserModel: K8sKind = {
+  label: 'User',
+  labelPlural: 'Users',
+  apiVersion: 'v1',
+  apiGroup: 'user.openshift.io',
+  plural: 'users',
+  abbr: 'U',
+  namespaced: false,
+  kind: 'User',
+  id: 'user',
+  crd: true,
+};
+
+export const GroupModel: K8sKind = {
+  label: 'Group',
+  labelPlural: 'Groups',
+  apiVersion: 'v1',
+  apiGroup: 'user.openshift.io',
+  plural: 'groups',
+  abbr: 'G',
+  namespaced: false,
+  kind: 'Group',
+  id: 'group',
+  crd: true,
+};
+
 // Cluster API resources
 // https://github.com/openshift/cluster-api
 export const MachineModel: K8sKind = {
@@ -847,6 +788,19 @@ export const MachineAutoscalerModel: K8sKind = {
   crd: true,
 };
 
+export const MachineHealthCheckModel: K8sKind = {
+  label: 'Machine Health Check',
+  labelPlural: 'Machine Health Checks',
+  apiVersion: 'v1beta1',
+  apiGroup: 'machine.openshift.io',
+  plural: 'machinehealthchecks',
+  abbr: 'MHC',
+  namespaced: true,
+  kind: 'MachineHealthCheck',
+  id: 'machinehealthcheck',
+  crd: true,
+};
+
 // Openshift cluster resources
 export const ClusterOperatorModel: K8sKind = {
   label: 'Cluster Operator',
@@ -978,3 +932,16 @@ export const ConsoleExternalLogLinkModel: K8sKind = {
   id: 'consoleexternalloglink',
   crd: true,
 };
+
+export const ConsoleYAMLSampleModel: K8sKind = {
+  label: 'Console YAML Sample',
+  labelPlural: 'Console YAML Samples',
+  apiVersion: 'v1',
+  apiGroup: 'console.openshift.io',
+  plural: 'consoleyamlsamples',
+  abbr: 'CYS',
+  namespaced: false,
+  kind: 'ConsoleYAMLSample',
+  id: 'consoleyamlsample',
+  crd: true,
+};
