@@ -17,17 +17,14 @@ trap copyArtifacts EXIT
 
 # don't log kubeadmin-password
 set +x
-export BRIDGE_KUBEADMIN_PASSWORD="$(cat "${INSTALLER_DIR}/auth/kubeadmin-password")"
+BRIDGE_KUBEADMIN_PASSWORD="$(cat "${INSTALLER_DIR}/auth/kubeadmin-password")"
+export BRIDGE_KUBEADMIN_PASSWORD
 set -x
-export BRIDGE_BASE_ADDRESS="$(oc get consoles.config.openshift.io cluster -o jsonpath='{.status.consoleURL}')"
+BRIDGE_BASE_ADDRESS="$(oc get consoles.config.openshift.io cluster -o jsonpath='{.status.consoleURL}')"
+export BRIDGE_BASE_ADDRESS
 
 # Add htpasswd IDP
 oc apply -f ./frontend/integration-tests/data/htpasswd-secret.yaml
 oc patch oauths cluster --patch "$(cat ./frontend/integration-tests/data/patch-htpasswd.yaml)" --type=merge
 
-# get the branch base position for a specific chromium version using https://omahaproxy.appspot.com/
-source ./chromium-version.sh
-
-./test-gui.sh ${1:-e2e}
-
-./test-ciphers.sh
+CHROME_VERSION=$(google-chrome --version) ./test-gui.sh "${1:-e2e}"
